#
# spec file for package cups-filters
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Summary:        OpenPrinting CUPS filters, backends, and cups-browsed
# See also http://www.linuxfoundation.org/collaborate/workgroups/openprinting/pdf_as_standard_print_job_format
License:        GPL-2.0-only AND GPL-2.0-or-later AND GPL-3.0-only AND MIT
Group:          Hardware/Printing
URL:            http://www.linuxfoundation.org/collaborate/workgroups/openprinting/cups-filters
# For a breakdown of the licensing, see COPYING file
# GPLv2:   filters: commandto*, imagetoraster, pdftops, rasterto*,
#                   imagetopdf, pstopdf, texttopdf
#         backends: parallel, serial
# GPLv2+:  filters: textonly, texttops, imagetops
# GPLv3:   filters: bannertopdf
# MIT:     filters: pdftoijs, pdftoopvp, pdftopdf, pdftoraster
Name:           cups-filters
# Normal version for official cups-filters releases is the upstream version (e.g. "Version: 1.0.49").
# For a current tarball cups-filters-1.0-yyyymmdd.tar.gz (e.g. cups-filters-1.0-20140326.tar.gz)
# the current tarball's date is added to the version to ensure a strictly increasing sequence
# "last version" < "current version" < "next version" e.g. "1.0.49" < "1.0.49.20140326" < "1.0.50"
# to verify this run: zypper vcmp 'last version' 'current version'
#       and also run: zypper vcmp 'next version' 'current version'
# e.g. zypper vcmp '1.0.49' '1.0.49.20140326' -> 1.0.49 is older than 1.0.49.20140326
#  and zypper vcmp '1.0.50' '1.0.49.20140326' -> 1.0.50 is newer than 1.0.49.20140326
Version:        1.28.17
Release:        2.2
# To get Source0 go to https://github.com/OpenPrinting/cups-filters/releases or use e.g.
# wget --no-check-certificate -O cups-filters-1.28.17.tar.gz https://github.com/OpenPrinting/cups-filters/releases/download/1.28.17/cups-filters-1.28.17.tar.gz
Source0:        cups-filters-%{version}.tar.gz
Patch0:         harden_cups-browsed.service.patch
# Upstream fix for https://bugs.linuxfoundation.org/show_bug.cgi?id=1421
# in https://github.com/OpenPrinting/cups-filters/commit/6db3b08d3b20332b1525b8dd1a47950381b8f637
# dowloaded via
# wget -O fix_upstream_bug_1421.patch https://github.com/OpenPrinting/cups-filters/commit/6db3b08d3b20332b1525b8dd1a47950381b8f637.patch
# and then removed the changes of the NEWS file from that patch because
# the NEWS changes do not apply on the sources of the pristine 1.20.0 release:
# Since cups-filters version 1.0.42 foomatic-rip is also provided by cups-filters.
# The foomatic-rip version that is provided by cups-filters is not specified in the cups-filters sources
# but on http://www.openprinting.org/download/foomatic/ the foomatic-filters-4.0-current.tar.gz
# dated 27-Mar-2014 (i.e. from today as of this writing) contains a VERSION.full file that reads "4.0.17.256"
# so that foomatic_rip_version (macro name can be only alphanumeric and '_' i.e. "foomatic-rip_version" does not work)
# is defined here accordingly but with one more additional trailing number '.1' to ensure that
# the sub-package cups-filters-foomatic-rip (see below) conflicts with any foomatic-filters package:
#   zypper vcmp '4.0.17.256' '4.0.17.256.1' -> 4.0.17.256 is older than 4.0.17.256.1
#   zypper vcmp '4.0.17.257' '4.0.17.256.1' -> 4.0.17.257 is newer than 4.0.17.256.1
%define foomatic_rip_version 4.0.17.256.1
Patch1:         require_cxx17.patch
# Patch2 cups-filters-1.28.15-0001-beh-backend-Use-execv-instead-of-system-CVE-2023-24805.patch
# is the upstream 0001-beh-backend-Use-execv-instead-of-system-CVE-2023-24805.patch
# backported to cups-filters-1.28.15
# Patch3 cups-filters-1.28.15-0002-beh-backend-Extra-checks-against-odd-forged-input-CVE-2023-24805.patch
# is the upstream 0002-beh-backend-Extra-checks-against-odd-forged-input-CVE-2023-24805.patch
# backported to cups-filters-1.28.15
# Patch4 cups-filters-1.28.15-0003-beh-backend-Further-improvements-CVE-2023-24805.patch
# is the upstream 0003-beh-backend-Further-improvements-CVE-2023-24805.patch
# backported to cups-filters-1.28.15
# Patch2 Patch3 Patch4 fix CVE-2023-24805: RCE in cups-filters, beh CUPS backend
# https://bugzilla.suse.com/show_bug.cgi?id=1211340
# https://github.com/OpenPrinting/cups-filters/commit/8f274035756c04efeb77eb654e9d4c4447287d65
Patch2:         cups-filters-1.28.15-0001-beh-backend-Use-execv-instead-of-system-CVE-2023-24805.patch
Patch3:         cups-filters-1.28.15-0002-beh-backend-Extra-checks-against-odd-forged-input-CVE-2023-24805.patch
Patch4:         cups-filters-1.28.15-0003-beh-backend-Further-improvements-CVE-2023-24805.patch
# Support for cups154 in the SLE12 legacy module is abandoned (by default SLE12 has CUPS 1.7.5)
# because newer cups-filters versions use stuff that is provided since CUPS > 1.5.4 so that it does
# no longer build with CUPS 1.5.4 so that cups-filters does not work with CUPS 1.5.4:
BuildRequires:  cups-devel > 1.5.4
BuildRequires:  pkgconfig
# pdftopdf
BuildRequires:  qpdf-devel >= 8.3.0
# pdftops
BuildRequires:  poppler-tools
# pdftoraster
BuildRequires:  ghostscript-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(poppler-cpp) >= 0.19
# _cupsImageReadEXIF in image.c called in image-jpeg.c image-tiff.c image-png.c see
# https://github.com/OpenPrinting/cups-filters/commit/2298d1fa0770737945b9c0dbe1c3dc690033ed3c
BuildRequires:  libexif-devel
# libijs
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  liblcms2-devel
# braille embossers
BuildRequires:  liblouis-devel
# Make sure we get postscriptdriver tags.
# suse_version >= 1330 means "after any SLE12 service pack and after any Leap 42.x"
# see https://en.opensuse.org/openSUSE:Build_Service_cross_distribution_howto
# and cf. cups.spec where the same test is used:
%if 0%{?suse_version} >= 1330
BuildRequires:  python3-cups
%else
BuildRequires:  python-cups
%endif
# cups-browsed
# "BuildRequires libavahi-devel" is insufficient
# (build fails at configure "checking for AVAHI_GLIB")
# "BuildRequires libavahi-gobject-devel" is too much
# (libavahi-gobject-devel requires libavahi-glib-devel and libavahi-devel)
# "BuildRequires libavahi-glib-devel" is sufficient
# (libavahi-glib-devel requires libavahi-devel)
BuildRequires:  libavahi-glib-devel
# autogen.sh
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  xz
BuildRequires:  pkgconfig(systemd)
%systemd_requires
# test requires
BuildRequires:  dejavu-fonts
# Conflict with CUPS < 1.6 because up to CUPS 1.5.4
# the following files are provided by the cups binary RPM package
# /usr/lib/cups/filter/commandtoescpx
# /usr/lib/cups/filter/commandtopclx
# /usr/lib/cups/filter/imagetops
# /usr/lib/cups/filter/imagetoraster
# /usr/lib/cups/filter/pdftops
# /usr/lib/cups/filter/rastertoescpx
# /usr/lib/cups/filter/rastertopclx
# /usr/lib/cups/filter/texttops
# /usr/lib/cups/backend/parallel
# /usr/lib/cups/backend/serial
# and the following files are provided by the cups-devel package
# /usr/share/cups/ppdc/escp.h
# /usr/share/cups/ppdc/pcl.h
Conflicts:      cups < 1.6
# Since version 1.14.0 there are no longer sub-packages (except cups-filters-devel).
# The separation of cups-filters into sub-packages was done to make it possible
# to use cups-filters on systems with the traditional CUPS < 1.6
# (i.e. on systems before the SLE12 code base)
# because parts of the cups-filters software conflict with traditional CUPS < 1.6,
# see the comments and package descriptions in older cups-filters.spec.
# But nowadays cups-filters can no longer be built with CUPS < 1.6 with reasonable effort,
# see the entry dated "Wed Oct  7 11:16:13 CEST 2015" in cups-filters.changes.
# On systems with CUPS >= 1.6 (i.e. since SLE12 GA / Leap 42.1) there is no good reason
# to keep cups-filters split into sub-packages and furthermore that split causes
# continuous (nowadays useless) efforts and bugs like
# https://bugzilla.opensuse.org/show_bug.cgi?id=1034877
# Therefore the cups-filters main package must provide
# all what was provided by its former sub-packages
# i.e. all sub-packages names and all explicit "Provides"
# and furthermore it obsoletes all the old sub-packages:
Provides:       cups-filters-ghostscript
Obsoletes:      cups-filters-ghostscript < %{version}
Obsoletes:      cups-filters-ghostscript-debuginfo
Provides:       cups-filters-cups-browsed
Provides:       gstoraster
Obsoletes:      cups-filters-cups-browsed < %{version}
Obsoletes:      cups-filters-cups-browsed-debuginfo
Provides:       cups-browsed
Provides:       cups-filters-foomatic-rip
Obsoletes:      cups-filters-foomatic-rip < %{version}
Obsoletes:      cups-filters-foomatic-rip-debuginfo
Provides:       foomatic-rip
# Provide foomatic-filters with the exact foomatic_rip_version
# see https://bugzilla.novell.com/show_bug.cgi?id=870621
# and conflict with any other foomatic-filters version because
# the following files are also provided by foomatic-filters
# /usr/lib/cups/filter/foomatic-rip /usr/share/man/man1/foomatic-rip
# Regardless that foomatic-filters exists only up to SLE11 and openSUSE 13.1
# it is still built in the OBS "Printing" project for current SLE12 and
# openSUSE Leap and Tumbleweed so that the conflict is still needed.
# The RPM documentation http://www.rpm.org/max-rpm/s1-rpm-depend-manual-dependencies.html
# and /usr/share/doc/packages/rpm/manual/dependencies (in rpm-4.8.0 in openSUSE 11.4)
# does not show a comparison operator for "not equal" so that two Conflicts are used:
Conflicts:      foomatic-filters < %{foomatic_rip_version}
Provides:       foomatic-filters = %{foomatic_rip_version}
Conflicts:      foomatic-filters > %{foomatic_rip_version}
# /usr/bin/pdftops (provided by poppler-tools)
# is needed (but not required for non-PostScript printers)
# to print PDFs on PostScript printers because in this case
# the CUPS filter chain is:
#  /usr/lib/cups/filter/pdftopdf
#  /usr/lib/cups/filter/pdftops
#  where /usr/lib/cups/filter/pdftops calls /usr/bin/pdftops
#  /usr/lib/cups/backend/...
# see https://bugzilla.novell.com/show_bug.cgi?id=868148
Recommends:     poppler-tools

%description
Contains backends, filters, and other software
that was once part of the core CUPS distribution
but is no longer maintained by Apple Inc.
In addition it contains additional filters
and software developed independently of Apple,
especially filters for the PDF-centric printing
workflow introduced by OpenPrinting and a daemon
to browse broadcasts of remote CUPS printers
and makes these printers available locally.
Since Ghostscript version 9.10 the CUPS filters
gstoraster and gstopxl are removed from Ghostscript.
Those filters are now provided by cups-filters.
Since cups-filters version 1.0.42 foomatic-rip
is also provided by cups-filters.
Since CUPS >= 1.6 the CUPS Browsing functionality
is dropped in CUPS. The OpenPrinting cups-browsed
is a daemon running in parallel to the CUPS daemon
to provide again basic CUPS Browsing functionality.
This way basic CUPS Browsing works on clients
with CUPS >= 1.6 when there are remote CUPS servers
of CUPS version 1.5 and older in the network.
Load-balancing (what CUPS <= 1.5 did via implicit classes)
is not supported with cups-browsed.

%package devel
Summary:        Development files for cups-filters
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
# Conflict with cups-devel < 1.6 because up to CUPS 1.5.4
# the following files are provided by the cups-devel package
# /usr/share/cups/ppdc/escp.h
# /usr/share/cups/ppdc/pcl.h
Conflicts:      cups-devel < 1.6

%description devel
This package contains the development files for cups-filters.

%prep
%autosetup -p1

%build
# Just do what is described in the upstream INSTALL file
# unless there is a really good reason not to do it this way
# and then it is probably worth submitting an upstream issue report to
# https://bugs.linuxfoundation.org for "Product: OpenPrinting" and "Component: cups-filters"
./autogen.sh
# No need to set our preferred architecture-specific flags for the compiler and linker
# via export CFLAGS="$RPM_OPT_FLAGS" and export CXXFLAGS="$RPM_OPT_FLAGS"
# because the RPM macro configure does that.
# --with-pdftops=pdftops - use Poppler instead of Ghostscript (see README)
# --enable-braille - enable Braille embosing filters, requires liblouis
# --disable-mutool - disable mupdf processing as we use ghostcript
%configure --disable-static \
           --disable-mutool \
           --disable-silent-rules \
           --enable-shared \
           --enable-imagefilters \
           --enable-braille \
           --with-pdftops=pdftops \
           --with-browseremoteprotocols=DNSSD,CUPS \
           --without-php \
	   --with-rcdir=no \
	   --with-test-font-path=/usr/share/fonts/truetype/DejaVuSans.ttf
make %{?_smp_mflags}

%check
make check %{?_smp_mflags}

%install
%make_install
# As band-aid for now remove the "# BrowseAllow cups.example.com" example line in cups-browsed.conf
# because currently hostnames do not work, see https://bugs.linuxfoundation.org/show_bug.cgi?id=1205
if grep -q '^# BrowseAllow cups.example.com' %{buildroot}%{_sysconfdir}/cups/cups-browsed.conf
then sed -i -e '/^# BrowseAllow cups.example.com/d' %{buildroot}%{_sysconfdir}/cups/cups-browsed.conf
else echo "No longer '# BrowseAllow cups.example.com' in cups-browsed.conf - clean up cups-filters.spec"
     exit 9
fi
# https://fedoraproject.org/wiki/Packaging_tricks#With_.25doc
mkdir __doc
mv %{buildroot}%{_datadir}/doc/cups-filters/* __doc
rm -r %{buildroot}%{_datadir}/doc/cups-filters
mv fontembed/README __doc/fontembed.README
# Install the cups-browsed.service systemd unit file from the upstream sources:
mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 utils/cups-browsed.service %{buildroot}%{_unitdir}
# Provide SUSE policy symlink /usr/sbin/rcFOO -> /etc/init.d/FOO
ln -s service %{buildroot}%{_sbindir}/rccups-browsed
# Don't ship libtool la files.
rm -f %{buildroot}%{_libdir}/lib*.la
# Not sure what is this good for
rm -f %{buildroot}%{_bindir}/ttfread

%pre
# For cups-browsed:
%service_add_pre cups-browsed.service
exit 0

%post
# For cups-browsed:
%service_add_post cups-browsed.service
# Re-configure dynamic linker run-time bindings:
/sbin/ldconfig
exit 0

%preun
# For cups-browsed:
%service_del_preun cups-browsed.service
exit 0

%postun
# For cups-browsed:
%service_del_postun cups-browsed.service
# Re-configure dynamic linker run-time bindings:
/sbin/ldconfig
exit 0

%files
# The files sections list all mandatory files explicitly one by one.
# In particular all executables are listed explicitly.
# This avoids that whatever configure magic might silently
# not build and install an executable when whatever condition
# for configure's automated tests is not fulfilled in the build system,
# (cf. https://bugzilla.novell.com/show_bug.cgi?id=526847#c9).
# When all mandatory files are explicitly listed,
# the build fails intentionally if a mandatory file was not built
# which ensures that already existing correctly built binary RPMs
# are not overwritten by broken RPMs where mandatory files are missing.
%license __doc/COPYING
%doc __doc/README __doc/AUTHORS __doc/NEWS __doc/fontembed.README
%config(noreplace) %{_sysconfdir}/cups/cups-browsed.conf
%{_unitdir}/cups-browsed.service
%{_sbindir}/cups-browsed
%{_sbindir}/rccups-browsed
%{_mandir}/man5/cups-browsed.conf.5.gz
%{_mandir}/man8/cups-browsed.8.gz
%{_bindir}/driverless
%{_mandir}/man1/driverless.1.gz
%{_bindir}/driverless-fax
%{_bindir}/foomatic-rip
%{_mandir}/man1/foomatic-rip.1.gz
%dir /usr/lib/cups
%dir /usr/lib/cups/driver
/usr/lib/cups/driver/driverless
/usr/lib/cups/driver/driverless-fax
%dir /usr/lib/cups/backend
# The wrapper backends beh and implicitclass must be installed with 0700 permissions
# so that cupsd runs them as root (backends with root-only permissions are run as root by cupsd)
# because otherwise wrapper backends cannot run other backends that need to run as root
# in particular the ipp backend runs as root and the implicitclass wrapper backend runs it
# to print via queues that are generated by cupsd-browsed,
# see https://github.com/OpenPrinting/cups-filters/issues/183#issuecomment-570196216
# and https://bugzilla.opensuse.org/show_bug.cgi?id=1178604
%attr(0700,root,root) /usr/lib/cups/backend/beh
%attr(0700,root,root) /usr/lib/cups/backend/implicitclass
# The parallel backend does not need to be run as root because cupsd runs backends by default as user lp group lp
# and the parallel port kernel device node /dev/lp0 has by default rw permissions for the group lp
%attr(0755,root,root) /usr/lib/cups/backend/parallel
# The cups-brf backend needs to run as root
# see https://bugzilla.redhat.com/show_bug.cgi?id=1657261
# and https://bugzilla.suse.com/show_bug.cgi?id=1186844
%attr(0700,root,root) /usr/lib/cups/backend/cups-brf
# Serial backend needs to run as root
# see https://bugzilla.redhat.com/show_bug.cgi?id=212577#c4
%attr(0700,root,root) /usr/lib/cups/backend/serial
# Explicit attr() mode not applicable to symlink /usr/lib/cups/backend/driverless
/usr/lib/cups/backend/driverless
/usr/lib/cups/backend/driverless-fax
%dir /usr/lib/cups/filter
%attr(0755,root,root) /usr/lib/cups/filter/bannertopdf
%attr(0755,root,root) /usr/lib/cups/filter/brftopagedbrf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/cgmtopdf
/usr/lib/cups/filter/cgmtopdf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/cmxtopdf
/usr/lib/cups/filter/cmxtopdf
%attr(0755,root,root) /usr/lib/cups/filter/commandtoescpx
%attr(0755,root,root) /usr/lib/cups/filter/commandtopclx
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/emftopdf
/usr/lib/cups/filter/emftopdf
%attr(0755,root,root) /usr/lib/cups/filter/foomatic-rip
%attr(0755,root,root) /usr/lib/cups/filter/gstoraster
%attr(0755,root,root) /usr/lib/cups/filter/gstopxl
%attr(0755,root,root) /usr/lib/cups/filter/gstopdf
%attr(0755,root,root) /usr/lib/cups/filter/imagetopdf
%attr(0755,root,root) /usr/lib/cups/filter/imagetops
%attr(0755,root,root) /usr/lib/cups/filter/imagetoraster
%attr(0755,root,root) /usr/lib/cups/filter/musicxmltobrf
%attr(0755,root,root) /usr/lib/cups/filter/pdftopdf
%attr(0755,root,root) /usr/lib/cups/filter/pdftops
%attr(0755,root,root) /usr/lib/cups/filter/pdftoraster
%attr(0755,root,root) /usr/lib/cups/filter/rastertoescpx
%attr(0755,root,root) /usr/lib/cups/filter/rastertopclm
%attr(0755,root,root) /usr/lib/cups/filter/rastertopclx
%attr(0755,root,root) /usr/lib/cups/filter/rastertops
%attr(0755,root,root) /usr/lib/cups/filter/rastertopdf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/svgtopdf
/usr/lib/cups/filter/svgtopdf
%attr(0755,root,root) /usr/lib/cups/filter/sys5ippprinter
%attr(0755,root,root) /usr/lib/cups/filter/vectortobrf
%attr(0755,root,root) /usr/lib/cups/filter/vectortopdf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/vectortoubrl
/usr/lib/cups/filter/vectortoubrl
%attr(0755,root,root) /usr/lib/cups/filter/texttopdf
%attr(0755,root,root) /usr/lib/cups/filter/texttops
%attr(0755,root,root) /usr/lib/cups/filter/texttotext
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/wmftopdf
/usr/lib/cups/filter/wmftopdf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/xfigtopdf
/usr/lib/cups/filter/xfigtopdf
# See the "./configure --help" output
#  --with-apple-raster-filter=rastertopdf|urftopdf
#    Select filter for Apple Raster input. Default:
#    rastertopdf for CUPS 2.2.2+, urftopdf for older CUPS
# and see in the NEWS file the CHANGES IN V1.13.0
#  - rastertopdf, urftopdf: As with libcupsimage from CUPS 2.2.2
#    on rastertopdf also understands Apple Raster and much better
#    than urftopdf does, use rastertopdf for Apple Raster
#    (image/urf) input files then. Also allow for manually
#    choosing by the ./configure command line.
# Because Factory/Tumbleweed uses CUPS in the Printing project for build
# (which is currently CUPS 2.2.3 as of this writing Fri Jun 2)
# the filter for Apple Raster input is rastertopdf
# so that /usr/lib/cups/filter/urftopdf must be excluded
# from the RPM files list for Factory/Tumbleweed.
# For the current suse_version value for openSUSE Factory see
# https://en.opensuse.org/openSUSE:Build_Service_cross_distribution_howto
# because that value changes:
%if 0%{?suse_version} <= 1320
%attr(0755,root,root) /usr/lib/cups/filter/urftopdf
%endif
# Filters for braille embosser support:
%attr(0755,root,root) /usr/lib/cups/filter/brftoembosser
%attr(0755,root,root) /usr/lib/cups/filter/imagetobrf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/imagetoubrl
/usr/lib/cups/filter/imagetoubrl
%attr(0755,root,root) /usr/lib/cups/filter/imageubrltoindexv3
%attr(0755,root,root) /usr/lib/cups/filter/imageubrltoindexv4
%attr(0755,root,root) /usr/lib/cups/filter/textbrftoindexv3
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/textbrftoindexv4
/usr/lib/cups/filter/textbrftoindexv4
%attr(0755,root,root) /usr/lib/cups/filter/texttobrf
%dir %{_datadir}/cups
%{_datadir}/cups/banners
# Shell helpers for braille embosser support:
%{_datadir}/cups/braille
%{_datadir}/cups/charsets
%dir %{_datadir}/cups/data
%{_datadir}/cups/data/*
%dir %{_datadir}/cups/drv
%{_datadir}/cups/drv/cupsfilters.drv
# Driver info files for braille embosser support:
%{_datadir}/cups/drv/generic-brf.drv
%{_datadir}/cups/drv/generic-ubrl.drv
%{_datadir}/cups/drv/indexv3.drv
%{_datadir}/cups/drv/indexv4.drv
%dir %{_datadir}/cups/mime
%{_datadir}/cups/mime/cupsfilters.types
%{_datadir}/cups/mime/cupsfilters.convs
%{_datadir}/cups/mime/cupsfilters-ghostscript.convs
%{_datadir}/cups/mime/cupsfilters-poppler.convs
# MIME conversion types and rules for braille embosser support:
%{_datadir}/cups/mime/braille.types
%{_datadir}/cups/mime/braille.convs
# CUPS PPD file compiler driver information files for braille embosser support:
%dir %{_datadir}/cups/ppdc
%{_datadir}/cups/ppdc/braille.defs
%{_datadir}/cups/ppdc/fr-braille.po
%{_datadir}/cups/ppdc/imagemagick.defs
%{_datadir}/cups/ppdc/index.defs
%{_datadir}/cups/ppdc/liblouis.defs
%{_datadir}/cups/ppdc/liblouis1.defs
%{_datadir}/cups/ppdc/liblouis2.defs
%{_datadir}/cups/ppdc/liblouis3.defs
%{_datadir}/cups/ppdc/liblouis4.defs
%{_datadir}/cups/ppdc/media-braille.defs
# PPD files:
%dir %{_datadir}/ppd
%{_datadir}/ppd/cupsfilters
# Libraries:
%{_libdir}/libcupsfilters.so.*
%{_libdir}/libfontembed.so.*

%files devel
%defattr(-,root,root)
%dir %{_datadir}/cups/ppdc
%{_datadir}/cups/ppdc/pcl.h
%{_datadir}/cups/ppdc/escp.h
%{_libdir}/libcupsfilters.so
%{_libdir}/libfontembed.so
%{_libdir}/pkgconfig/libcupsfilters.pc
%{_libdir}/pkgconfig/libfontembed.pc
%{_includedir}/cupsfilters
%{_includedir}/fontembed

%changelog
* Fri Feb  2 2024 Johannes Meixner <jsmeix@suse.com>
- Removed outdated and obsoleted "Requires: cups > 1.5.4"
  which was used to require a sufficient CUPS version
  at times when also CUPS <= 1.5.4 was available
  but it was not meant to require CUPS (boo#1216560)
* Wed Jan 24 2024 Johannes Meixner <jsmeix@suse.com>
- Version upgrade to 1.28.17
  See https://github.com/OpenPrinting/cups-filters/releases
  Bug fix release, to more reliably discover all printer
  capablities from driverless printers, especially borderless
  printing, and to preferably use Apple Raster instead of
  PWG Raster or PCLM.
  * libcupsfilters: In PPD generator create only one *cupsFilter2:
    line for raster. Only use the most desirable/reliable format,
    usually Apple Raster (Issue #498).
  * libcupsfilters: In get_printer_attributes() poll
    media-col-database separately if needed. On some printers
    one gets media-col-database only this way. Often it reveals
    important functionality, like for example borderless printing
    (Issue #492).
  * libcupsfilters: Let PPD generator also parse media-col-ready
    IPP attribute. media-col-ready lists the loaded media,
    in contrary to media-ready, as list of complete descriptions
    of the media (media-col data structure). This often lists also
    variants like borderless (it is the same physical paper).
    Especially useful when media-col-database is not available
    (Issue #492).
  * libcupsfilters: In generate_sizes() consider all
    margin alternatives. When generating the PPD file
    for a driverless printer, and in the
    media-{left,right,top,bottom}-margin-supported printer
    IPP attributes there was more than 1 value, the first value
    (which often was the 0 for borderless printing) was not
    considered, leaving the borderless functionality of many
    printers undiscovered (Issue #492).
  Issues are those at
  https://github.com/OpenPrinting/cups-filters/issues
- Version upgrade to 1.28.16
  See https://github.com/OpenPrinting/cups-filters/releases
  Bug fix release, to make images be printed in their original
  size with "print-scaling=none" and to not use deprecated data
  types for reading TIFF images.
  * imagetoraster, imagetopdf, libcupsfilters: Added support
    for reading the resolution of an image from its EXIF data
    when loading it. This way we get the image reproduced in
    its original size with "print-scaling=none" (Issue #362).
  * libcupsfilters: Replaced deprecated data types uint16 and
    uint32. The function to read TIFF image files via libtiff
    in cupsfilters/image-tiff.c uses the deprecated types
    uint16 and uint32. The replacements for these types are
    uint16_t and uint32_t.
  Issues are those at
  https://github.com/OpenPrinting/cups-filters/issues
* Wed May 17 2023 Johannes Meixner <jsmeix@suse.com>
- cups-filters-1.28.15-0001-beh-backend-Use-execv-instead-of-system-CVE-2023-24805.patch
  cups-filters-1.28.15-0002-beh-backend-Extra-checks-against-odd-forged-input-CVE-2023-24805.patch
  cups-filters-1.28.15-0003-beh-backend-Further-improvements-CVE-2023-24805.patch
  are the upstream
  0001-beh-backend-Use-execv-instead-of-system-CVE-2023-24805.patch
  0002-beh-backend-Extra-checks-against-odd-forged-input-CVE-2023-24805.patch
  0003-beh-backend-Further-improvements-CVE-2023-24805.patch
  backported to cups-filters-1.28.15
  to fix CVE-2023-24805: RCE in cups-filters, beh CUPS backend
  (bsc#1211340) and
  https://github.com/OpenPrinting/cups-filters/commit/8f274035756c04efeb77eb654e9d4c4447287d65
* Wed Mar  1 2023 Adam Majer <adam.majer@suse.de>
- require_cxx17.patch: qpdf dependency is using std::string_view
  which is a c++17 feature... so we can't use c++11... Maybe it
  made sense to force c++11 at some point when it was not default,
  but with new compilers, we are actually downgrading features sets.
- removed spec configure references to filter (ijs, opvp)
  that were removed in version 1.25
* Fri Jun 24 2022 Martin Wilck <mwilck@suse.com>
- Spec file: Removed URL from source line
* Thu Jun  9 2022 mwilck@suse.com
- Update to version 1.28.15:
  * pdftops: Identify old LaserJets more precisely for swicth to Poppler
  * Make pdftopdf also work correctly with auro-rotating off
  * libcupsfilters: Make pdftopdf() correctly working with "landscape" option
  * rastertopdf: Filter fails if no PCLm default resolution given by printer
  * pdftopdf: Fix N-up printing with long-edge-first
  * libcupsfilters: In pdftopdf() fix cropping with long-edge-first
  * pdftops: Use Poppler for all Apple LaserWriter models
* Thu Jun  9 2022 mwilck@suse.com
- Enable OBS source services. Stay at 1.28.12 for now.
  * add _service file
* Tue Mar 22 2022 Aurélien Joga <aurelienjoga@gmail.com>
- Version upgrade to 1.28.12
  * imagetoraster, imagetopdf: Fixed comparison of the image size
    with the page size for print-scaling=auto. The image size
    in pixels was compared with the page size in PostScript
    points (1/72 inch).
  * imagetoraster, imagetopdf: Fixed the "print-scaling=none"
    (crop-to-fit) mode, also use crop-to-fit always when requested,
    do not fall back to fit-to-page when the image size differs
    significantly from the page size (Issue #362).
  * libcupsfilters: Changed the default PPI resolution for images
    as input files from 128 to 200 (Pull request #446).
  * implicitclass: Do not check availability of "gs" and "pdftops"
    executables, instead, check by the presence of "gstoraster"
    and "pdftoraster" filters whether we have configured
    cups-filters for Ghostscript and/or Poppler use.
  * libcupsfilters: In the PPD generator for the driverless
    utility and cups-browsed add "*cupsFilter2: ..." lines for
    all supported driverless data formats (PDF, Apple/PWG Raster,
    PCLm), and add lines for legacy data formats (PCL, PostScript)
    only if no driverless formats available.
  * libcupsfilters: Always use encryption for ipps. RFC7472
    requires that 'ipps' must be used over HTTPS, but the
    driverless utility does not enforce encryption
    (Pull request #433).
  * serial: Add a 10-msec sleep and at the end add a tcdrain().
    For some unknown reason, every printing file need sleep a
    little time to make sure the serial printer receive data
    is right (Pull request #431).
  * libcupsfilters: Fix resolver functions for DNS-SD-based URIs,
    to make resolve_uri() also work when DEVICE_URI env variable
    is set and to make ippfind_based_uri_converter() not
    re-direct stdin.
  * pdftopdf: Set default for print-scaling to avoid
    "should never happem" log messages and undefined behavior.
  * pdftopdf: Fix orientation-requested = 0. Consider this as
    automatic selection and not as error.
  * pdftopdf: Fixed all combinations of print-scaling and
    number-up for printers with asymmetric margins
    (top != bottom or left != right) and for input files
    containing pages with different sizes and/or orientations.
    Fixes backported from 2.x branch.
  * pdftopdf: Add 2%% tolerance for input size larger than output
    page when "print-scaling=auto" or "print-scaling=auto-fit"
    is used and too large input pages should be scaled, fitting
    documents not. This prevents a random-looking behavior if
    input and output page size seem to be equal, but in reality
    there are slight differences between size dimensions.
- Version upgrade to 1.28.11
  * libcupsfilters: Let PPD generator take default ColorModel
    from printer (CUPS issue #277).
  * Braille: In vectortopdf check inkscape version to call inkscape
    with the correct command line (Issue #315, Pull request #443).
  * Build system: Make missing DejaVuSans.ttf non-fatal
    in ./configure as the font is only needed for test programs,
    not for actual use of cups-filters (Issue #411).
  * libcupsfilters: In imagetoraster() fixed crash with SGray
    (Issue #435).
  * cups-browsed: Naming of local queues is matched to
    CUPS' current naming of temporary queues (no leading or
    trailing underscores), to avoid duplicates in print dialogs
    which support CUPS' temporary queues.
  * libcupsfilters: Make cupsRasterParseIPPOptions() work
    correctly with PPDs (Issue #436).
  * libcupsfilters: Let colord_get_profile_for_device_id()
    not return empty file name, to avoid error messages
    in CUPS error_log.
  * foomatic-rip: Debug message was wrongly sent to stdout
    and not to log (Issue #422).
- Version upgrade to 1.28.10
  * Sample PPDs: Add borderless page size definitions to
    Generic PDF Printer, HP Color LaserJet CM3530 MFP PDF,
    and Ricoh PDF Printer PPD files.
  * Sample PPDs: From the PDF PPD files removed the unneeded
    "*cupsFilters2: ..." line. For CUPS it does not make any
    difference.
  * libcupsfilters: Fixed pdftopdf filter to correctly support page
    ranges without upper limit, like "10-" (Pull request #399).
  * libcupsfilters: Use wildcard tag (IPP_TAG_ZERO) search for
    "media-type" and "media-type-supported" in the PPD generator
    (Pull request #398).
  * implicitclass, parallel: Added missing newlines at error
    messages.
  * libfontembed: Removed unneeded fontembed/main.c and ttfread
    executable. Eliminates the dependency on DejaVuSans.ttf
    (Issue #386).
  * gstoraster: Refactor the filter a little to clarify handling
    of page counts and set job-impressions for TotalPageCount in
    PWG-Raster header (Pull request #394).
  * cups-browsed: Make NotifLeaseDuration configurable and renew
    after half the lease duration not 60 sec before end. The early
    renewal improves reliability on busy systems a lot. For easier
    development and debugging short durations from 300 sec on can
    get selected (Pull request #378).
- Version upgrade to 1.28.9
  * libcupsfilters: Silenced compiler warnings
  * libcupsfilters: Removed duplicate code in the apply_filters()
    function.
  * driverless: If there are no driverless IPP printers available
    let "driverless" terminate with exit code 0 and not 1, to
    follow CUPS' standard of backends in discovery mode
    terminating with 0 if there are no appropriate printers
    found (Issue #375).
  * gstoraster, foomatic-rip: Fixed Ghostscript command line for
    counting pages as it took too long on PDFs from evince when
    printing DjVu files (Issue #354, Pull request #371,
    Ubuntu bug #1920730).
  * cups-browsed: Renamed ldap_connect() due to conflict in new
    openldap (Issue #367, Pull request #370).
  * pdftoraster: Free color data after processing of each page
    (Pull request #363).
  * cups-browsed: Always save "...-default" option entries from
    printers.conf, regardless of presence or absense of PPD file
    (Pull request #359).
  * cups-browsed: Start after network-online.target
    (Pull request #360).
  * texttopdf: Set default margins when no PPD file is used
    (Pull request #356).
- harden_cups-browsed.service.patch adapted to cups-filters-1.28.12
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400), see
  https://en.opensuse.org/openSUSE:Security_Features#Systemd_hardening_effort
  Added patch harden_cups-browsed.service.patch
* Tue Jun  8 2021 jsmeix@suse.de
- The cups-brf backend needs to run as root
  see https://bugzilla.redhat.com/show_bug.cgi?id=1657261
  (bsc#1186844)
* Tue May 25 2021 jsmeix@suse.de
- Version upgrade to 1.28.8
  * libcupsfilters: Made check whether the driverless PPD to
    generate should be a fax out PPD more reliable (Issue #343).
  * foomatic-rip: Options in the 5th command line argument of
    the CUPS filter command line are separated only by white
    space and not by comma, also make sure that an option "none"
    is not considered a custom page size (Issue #348).
  * implicitclass: Raise timeout for cups-browsed's answer from
    20s to 60s (Pull request #346).
  * libcupsfilters: In the PPD generator really give priority to
    Apple Raster against PDF (Issue #331).
- Version upgrade to 1.28.7
  * driverless: Removed the support quality check from Pull
    request #235 as it takes significant time for each printer
    being listed, making cups-driverd (`lpinfo -m`) timing out
    when there are many printers (OpenPrinting CUPS issue #65).
  * libcupsfilters: In the PPD generator give priority to Apple
    Raster against PDF (Issue #331).
  * libcupsfilters: Added NULL check when removing ".Borderless"
    suffixes from page size names (Issue #314, Pull request #328).
  * libcupsfilters: In the cupsRasterParseIPPOptions() map the
    color spaces the same way as in the PPD generator
    (Issue #326, Pull request #327).
  * libcupsfilters: Fixed addition of grayscale mode in
    generated PPD files, to avoid duplicate entries
    (OpenPrinting CUPS issue #59).
- Version upgrade to 1.28.6
  * libcupsfilters: In generated PPDs add a grayscale mode if
    there are only color printing modes (from OpenPrinting CUPS).
  * libcupsfilters: In generated PPDs add an "OutputBin" option
    also if it has only one choice (OpenPrinting CUPS pull
    request #18).
  * libcupsfilters: Generated PPDs could have an "Unknown"
    default InputSlot (OpenPrinting CUPS issue #44).
  * cups-browsed: Removed unneeded IPP attribute additions
    preventing the created local queues from preserving a
    location or description the user assigns to them (Issue #323).
  * cups-browsed: Removed all calls of the resolve_uri() function
    of libcupsfilters, as these are not actually needed and in case
    the supplied DNS-SD-based URI is not resolvable, the function
    gets stuck for ~5 seconds.
  * cups-browsed: Fixed several memory leaks, mainly from the
    code to merge printer IPP attributes for clusters
    (Pull request #322).
  * cups-browsed: Silenced compiler warning.
  * foomatic-rip: Fix infinite loop and input from file on raw
    printing (Pull request #318).
  * foomatic-rip: Remove temporary file created during pdf-to-ps
    conversion (Pull request #313).
- Version upgrade to 1.28.5
  * cups-browsed: UUID from IPP response was used after its
    pointer was freed by ippDelete() (Pull request #311).
- Version upgrade to 1.28.4
  * driverless: Avoid duplicate PPD list entries from the same
    device via UUID
  * driverless: Reduce ippfind calls by "driverless" and
    "driverless-fax"called by CUPS. Let "driverless list" list
    both print and fax PPDs and "driverless-fax list" do nothing.
  * driverless: Avoid duplicate listings in printer discovery,
    by "driverless-fax" not listing any URI as "driverless"
    lists them all already.
  * driverless: Vastly improve performance by doing only one
    ippfind call instead of two (IPP, IPPS) as ippfind accepts
    more than one reg type on the command line.
  * Sample PPDs: Corrected manufacturer name in
    Fuji_Xerox-DocuPrint_CM305_df-PDF.ppd.
- Version upgrade to 1.28.3
  * libcupsfilters, cups-browsed: Fixed inconsistency between
    resolvers for DNS-SD-based URIs, resolve_uri() and
    ippfind_based_uri_converter(). Now both return a freeable
    string.
  * libcupsfilters: Fix uninitialized buffer and parsing ippfind
    output in ippfind_based_uri_converter() function
    (Issue #308, Pull request #309).
- Version upgrade to 1.28.2
  * driverless: Free allocated memory, use MAX_OUTPUT_LEN
    (Pull request #304).
  * driverless: Make the two ippfind tasks(for IPP
    and IPPS) run in parallel (Pull request #302, #305, #306).
  * braille: Support new liblouis tables not containing a
    display name (Pull request #303)
  * Build system: Let ./configure not error out when there is
    more than one DejaVuSans.ttf test font candidate (Issue #300).
  * cups-browsed: Crash when a remote printer set as default gets
    removed, due to missing variable in printf() call (Issue #299).
  * libcupsfilters: Removed all signal handling and global
    variables from get_printer_attributes() and
    ippfind_based_uri_converter(). This is overkill for these
    quick operations and causes problems when shutting down
    cups-browsed (Issue #298).
- Version upgrade to 1.28.1
  * COPYING: Fixed several typos
  * libcupsfilters: Fixed typo in log message of
    get_printer_attributes functions.
  * cups-browsed: Fixed typos in configuration file and man page
  * libcupsfilters: Let the PPD generator not suffix page size
    names with ".Borderless" if all page sizes would get this
    suffix, for example for printers which generally print
    borderless.
  * libcupsfilters: Added "faxPrefix" option for generated IPP Fax
    Out PPDs, so that this option also appears in print dialogs.
  * driverless: List addresses for local services correctly when
    using "--std-ipp-uris" (with "localhost" hostname).
  * driverless: Make calls of the ippfind utility somewhat faster,
    setting the timeout of ippfind to automatic.
  * libcupsfilters: Resolve DNS-SD-based URIs for local services
    correctly (using hostname "localhost").
  * libcupsfilters: In get_printer_attributes() functions do not
    try to convert URIs which are not DNS-SD-based (Issue #294).
  * libcupsfilters: In get_printer_attributes() functions also
    support URIs with "dnssd://..." scheme.
  * libcupsfilters: Moved signal handling back into main
    function of the get_printer_attributes() variants, it got
    moved out accidentally.
  * driverless: For generating a PPD, independent whether via
    "driverless URI" or "driverless cat URI", always allow CUPS
    driver URIs (prefixed with "driverless: " or
    "driverless-fax:") and pure IPP URIs.
  * driverless: Accept clean IPP URIs also for 'driverless cat ...'
    (Issue #295, Pull request #296).
  * driverless-fax: Do not use fixed path for call of driverless
    itself (Pull request #293).
- Version upgrade to 1.28.0
  * driverless, driverless-fax, libcupsfilters: Added IPP Fax
    Out support. Now printer setup tools list an additional fax
    "driver".  A fax queue is created by selecting this driver.
    Jobs have to be sent with "-o phone=12345" to supply
    the destination phone number (Pull request #280).
  * libfontembed: Silenced warning with gcc 10.x
    (Pull request #287).
  * cups-browsed: Added ./configure
    options --enable-saving-created-queues
    and --with-remote-cups-local-queue-naming
    (Pull request: #253, #285).
  * cups-browsed: Fixed several memory leaks, mainly from
    the code to merge printer IPP attributes for clusters
    (Pull request #281, #283).
  * driverless: Added "--std-ipp-uris" command line option to
    show listed URIs in standard hostname-based form (not the
    CUPS DNS-SD-service-name-based form. Only for manual call of
    the utility, for debugging purposes (Pull request #277).
  * libfontembed: Removed assert() calls which cause crashes
    when unsupported emoji fonts are installed (Issue #254,
    Pull request #276).
  * driverless: Added support for IPPS (use "ipps://..." URIs if
    possible, Issue #251, Pull request #270, #273).
  * gstoraster, gstopdf: When converting PostScript to PDF use
    the "pdfwrite" output device with "-dPDFSETTINGS=/default"
    instead of with "-dPDFSETTINGS=/printer". This reproduces
    bitmaps in the PostScript file with their original image
    quality (Issue #272).
  * cups-browsed: Limit log file size and add backup file for
    previous log entries. Introduced the configuration option
    DebugLogFileSize in cups-browsed.conf to set the actual limit
    in kilobytes or 0 to get the old behavior of an unlimited
    size for the log file (Issue #260, Pull request #267).
  * gstoraster, gstopdf: Do not apply margins when output format
    is PDF, as then we convert an incoming PostScript file to
    PDF (pre-pdftopdf) and do not prepare the pages for the
    printer (post-pdftopdf, Issue #250).
  * cups-browsed: Do not write any log messages directly to
    stderr, there were some concerning timeouts on queue
    creation (Issue #260).
  * Build system: Fix cross-compilation without DejaVu test font
    in configure.ac (Issue #262, Pull request #263).
  * libcupsfilters: Respect the fact that PPD keywords
    are case-sensitive when adding "*cupsManualCopies: True" in
    PPD file (Issue #242).
  * libcupsfilters: Older versions of libcups (< 2.3.1)
    had the enum name for fold-accordion finishings mistyped.
    Added a workaround.
  * cups-browsed: Remove left-over local queues from the previous
    session more quickly when CUPS legacy browsing is turned on.
  * cups-browsed: Left-over local queues from the previous
    session for which the corresponding remote printer did not
    appear again did not get removed as they were considered
    externally overwritten.
  * gstoraster, gstopdf: Add option "-dDoNumCopies" to Ghostscript
    command line if we are outputting PDF (called via gstopdf
    wrapper) and the number of copies supplied to CUPS is 1 (4th
    command line argument). In this case we convert incoming
    PostScript to PDF and need to respect  embedded PostScript
    commands to implement the number of copies (Issue #255,
    CUPS Issue #5796, OpenSUSE bug #1173345).
  * imagetoraster: Potential null dereference fix (when no valid
    PPD is supplied, Pull request #256).
  * cups-browsed: Call cupsGetNamedDest() only if
    "OnlyUnsupportedByCUPS No"
  * Sample PPDs: Corrected ColorModel default for Generic PWG
    Raster PPD to Color (Pull request #247).
  * cups-browsed: Mark the temp queue as cups-browsed-generated
    during setting printer-is-shared (Pull request #246).
  * cups-browsed: Remove mentions of README and AUTHORS files in
    the man page (Pull request #244).
  * pclmtoraster: Added new filter to extract Raster data from
    raster-only PDF files, here for the special case of PCLm
    files (Pull request #243, #257).
  * Sample PPDs: In Generic-PDF_Printer-PDF.ppd add option to switch
    between color and grayscale printing (Pull request #237).
- Version upgrade to 1.27.5
  * cups-browsed: Do not remove the created local queues on
    shutdown, to avoid their re-creation on restart, so that
    desktops get no cluttered with notifications of new queues
    being created. One can return to the old behavior via
    "KeepGeneratedQueuesOnShutdown No" in cups-browsed.conf
    (Ubuntu bug #1869981, #1878241).
  * cups-browsed: Do not accept DNS-SD broadcasts of IPPS type
    of "remote" CUPS queues of another CUPS instance on the
    local machine. This way we get a local queue pointing to
    such a printer only in unencrypted version (IPP). For some
    reason printing from one CUPS server to another on the same
    machine works only unencrypted.
  * foomatic-rip: Map two-sided-short-edge to DuplexTumble
    (Pull request #236)
  * Build system: In configure.ac use AS_IF instead of
    AC_CHECK_FILE for font check (Issue #239, Pull request #240)
  * cups-browsed: Cleaned up code for determining to which CUPS
    server (host/port/domain socket) to connect, so that connection
    via DomainSocket cups-browsed.conf directive, CUPS_SERVER and
    IPP_PORT environment variables and all defaults and methods
    of libcups, including CUPS' client.conf work.
  * gstoraster, rastertopdf: Do not pass NULL to fprintf()
    (Pull request #230).
  * libcupsfilters: Silence compiler warning (Pull request #229).
- Version upgrade to 1.27.4
  * libcupsfilters, cups-browsed: Fix memory issues in
    ppdgenerator and cups-browsed (Pull request #226).
  * pdftops: Mention cups-filters README, CUPS README in debug log
    (Pull request #225).
  * pdftopdf, gstoraster, foomatic-rip: Use "-dSAFER" Ghostscript
    option, instead of the deprecated "-dPARANOIDSAFER"
    (Pull request #224).
  * Build System: Replace '==' in configure.ac test with '=', as
    the former is a bashism (Pull request #222).
- Version upgrade to 1.27.3
  * cups-browsed: Allow sharing local queues pointing to remote
    CUPS queues and re-sharing printers discovered via
    BrowsePoll by default, using AllowResharingRemoteCUPSPrinters
    and NewBrowsePollQueuesShared directives in cups-browsed.conf
    (Issue #101, Pull request #218).
  * driverless: Correctly unlink temporary file when generating
    PPD file (Pull request #220).
  * cups-browsed: Fixed memory leaks (Pull request #219).
  * foomatic-rip: PDF page count side-loads the PDF file to count
    the pages in, so it cannot be run in -dSAFER mode. Run even
    in -dNOSAFER mode to override the -dSAFER default of newer
    Ghostscript versions. This should not cause a security problem
    as we do not take an input file which could do arbitrary
    side-loads but we run hard-coded PostScript commands instead
    (Issue #216).
  * libfontembed: Add checks to the test programs to not segfault
    if the test font file is not found (Pull request #214).
  * Build System: Let ./configure fail if the supplied test font
    file path (or the default) does not exist (Pull request #214),
    also use the "find" command to find the test font file
    DejaVuSans.ttf under /usr/share/fonts, as every
    distribution has it somewhere else.
- fix_upstream_issue348.patch is no longer needed because
  it is now fixed in the upstream sources, see the above
  entry about "Issue #348". Entries like "Issue #NNN" or
  "Pull request #NNN" mean cups-filters upstream issues
  or cups-filters upstream GitHub pull requests at
  https://github.com/OpenPrinting/cups-filters
* Thu Apr 15 2021 jsmeix@suse.de
- fix_upstream_issue348.patch fixes
  https://github.com/OpenPrinting/cups-filters/issues/348
  foomatic-rip segfaults with 'job-sheets=none,none'
  but works with 'job-sheets=none'
  (bsc#1182893)
* Tue Nov 10 2020 jsmeix@suse.de
- The wrapper backends /usr/lib/cups/backend/beh
  and /usr/lib/cups/backend/implicitclass must be installed
  with 0700 permissions so that cupsd runs them as root
  (backends with root-only permissions are run as root by cupsd)
  because otherwise wrapper backends cannot run other backends
  that need to run as root in particular the ipp backend runs
  as root and the implicitclass wrapper backend runs it
  to print via queues that are generated by cupsd-browsed,
  see the upstream issue
  https://github.com/OpenPrinting/cups-filters/issues/183
  (boo#1178604).
* Thu Mar  5 2020 Dmitry Roshchin <dmitry_r@opensuse.org>
- Update to 1.27.2
  * foomatic-rip: In some PostScript input files it was possible
    that option settings did not get inserted or lines inserted
    on the wron place (Issue #208, Pull request #210).
  * foomatic-rip: For the PDF page count call Ghostscript in
    sandbox mode and fix pointer arithmetics (Pull request #212).
  * foomatic-rip: Zero-page-job handling changes made the last
    page of PostScript files not printed, also turning one-page
    jobs into zero-page jobs (Issue #200, Issue #206, Issue #208,
    Pull request #209, Pull request #210, Pull request #211).
  * cups-browsed: check_printer_with_option() function:
    Initialize the value, add further checks, freeing memory and
    stop allocating magic numbers (Pull request #204).
  * cups-browsed: Additional checks against crashes in the
    is_local_hostname() function (Ubuntu bug #1863716)
* Wed Feb 19 2020 Javier Llorente <javier@opensuse.org>
- Update to 1.27.1
  * libcupsfilters: Let the PPD generator not put any dashes into
    the PPD option and choice names when translating them from IPP
    attribute names, to avoid that on the back-translation by CUPS
    no double-dashes are generated. This broke paper tray
    selections with tray names like "tray-1", "tray-2", ...
    (Issue #192, Issue #201, Debian bug #949315).
  * foomatic-rip: Fixed segfault when PRINTER environment variable
    is not supplied.
  * pdftopdf, pdftops, gstoraster, gstopdf, gstopxl, rastertoescpx,
    rastertopclx, foomatic-rip: Handle zero-page jobs (Issue #117,
    Pull request #196, Pull request #197, Pull request #198,
    Pull request #200).
  * texttopdf: Added support for CJK (double-width) fonts
    (Issue #135, Pull request #199).
  * cups-browsed: Switched default for "CreateIPPPrinterQueues"
    from "local-only" to "All". The configure script options
    "--enable-auto-setup-local-only" and
    "--enable-auto-setup-driverless-only" can be used
    to change this default (Debian bug #921252).
  * rastertoescpx: Fixed wrong freeing of a buffer.
  * pdftops: Added options "crop-to-fit" and "fill" to the pdftopdf
    options which the pstops called by pdftops should not apply a
    second time.
  * pdftops: Added missing "-sstdout=%%stderr" to Ghostscript
    command line, to assure that all messages are redirected
    to stderr and do not mix up with the output data.
- Drop add-cstring-include.patch: already present upstream
- Drop foomatic-rip-fix-compilation-with-fno-common.patch: already
  present upstream
* Thu Jan  9 2020 Martin Wilck <mwilck@suse.com>
- Fix compilation with -fno-common, in preparation for gcc 10
  (boo#1160387)
  * Added foomatic-rip-fix-compilation-with-fno-common.patch
  (merged upstream as commit e6c5025)
* Tue Sep  3 2019 Ismail Dönmez <idonmez@suse.com>
- Add add-cstring-include.patch to include cstring for memcpy
  and strcmp
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Fri Jun  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.25.0:
  * pdftoijs, pdftoopvp: Removed these deprecated filters
    completely as there is no demand for them any more. They also
    used unstable, undocumented APIs of Poppler.
  * pdftoraster: Changed from using unstable, undocumented APIs of
    Poppler to stable, documented ones, to improve maintainability
    of this filter, and with it of the cups-filters package.
  * libcupsfilters: Added support for color spaces CMY and RGBW
    when using filters without PPD file (mainly for development and
    debugging, option "print-color-mode" with values "cmy-XX" and
    "rgbw-XX" with XX being the number of bits per color).
- Changes from version 1.24.0:
  * cups-browsed: Integration of Deepak Patankar's Google Summer of
    Code 2018 project with the main goal of clustering different
    printers and automatically selecting the destination printers
    by job content and option/attribute settings.
  * cups-browsed, implicitclass: Support for mixed clusters of
    remote CUPS queues and IPP network printers. For this PPD files
    of remote CUPS queues are generated by cups-browsed based on
    IPP queries, as for native IPP printers, the number of jobs for
    load balancing is polled in a way that it works also with
    native IPP printers, the implicitclass backend sends jobs
    directly to the printer instead of re-queueing them via CUPS.
  * cups-browsed: Merge IPP attributes of several printers to
    combined attributes for the cluster to generate the cluster's
    PPD file, including PPD constraints for option combinations not
    fulfillable by any of the member printers, and finding
    reasonable, non-conflicting default settings.
  * cups-browsed: Selection algorithm for the destination printer
    for a job sent to the cluster. Based on the job settings
    requested such as page size, media type, print quality, the
    best most suitable printer in the cluster for the job will be
    selected.
  * cups-browsed, implicitclass: Filter jobs to clusters already
    locally. Due to the fact that a cluster's member printers are
    not exclusively non-raw CUPS queues with the complete filtering
    framework on the remote server, but also native IPP printers,
    we need to support generic driverless printers as destination.
    So we cannot pass on the input data unfiltered but need to
    filter locally. We let the cluster's PPD file emulate a PDF
    printer, letting the local CUPS queue of the cluster run
    pdftopdf and any pre-filters to turn the input into PDF and we
    let the implicitclass backend turn PDF into a format understood
    by the destination printer, supporting the 4 formats of
    driverless IPP printing: PDF, PWG Raster, Apple Raster, PCLm.
- Drop libpoppler-cpp0, libpoppler-devel and libpoppler-glib-devel
  BuildRequires.
- Add pkgconfig(poppler-cpp) BuildRequires following upstream
  changes.
* Fri May 31 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.23.0:
  * This release adds support for the "print-scaling" IPP attribute
    and has the code for the support of MuPDF as PDF renderer
    vastly simplified.
  * pdftops, mupdftoraster: Let pdftops call mutool directly and so
    that it directly outputs PostScript, eliminating the need to
    call the mupdftoraster and rastertops filters.
  * mupdftoraster: Reduced the use of temporary files from 3 to
    just one.
  * imagetopdf, imagetoraster, pdftopdf: Add support for
    print-scaling option.
- Changes from version 1.22.6:
  * Bug fix release, to address a further issue of cups-browsed
    removing user-created print queues, to make
    grayscale/monochrome PostScript jobs of colored input file
    actually output grayscale/monochrome files, to fix several bugs
    when using MuPDF as PDF renderer, and to silence compiler
    warnings.
* Mon Apr  8 2019 jsmeix@suse.de
- Version upgrade to 1.22.5
  * foomatic-rip: Changed Ghostscript call to count pages in a
    PDF file to use "runpdfbegin" and not the undocumented
    Ghostscript internal "pdfdict", so that it works with
    Ghostscript 9.27 and later (Debian bug #926576,
    Arch Linux bug #62251, openSUSE boo#1131771,
    cups@cups.org mailing list thread
    https://lists.cups.org/pipermail/cups/2019-April/074563.html).
- Version upgrade to 1.22.4
  * cups-browsed: Fix broken trailing space removal on
    "NickName" (Pull request #103).
  * pdftops: Emit PostScript Level 2 instead of Level 3 for
    Brother PostScript printers as at least some of them
    report to support level 3 but ontly work with Level 2
    (Ubuntu bug #1306849, comment #42).
  * bannertopdf: When multiplying the page for N-up or Duplex
    printing one page too much was generated (Issue #102).
- Version upgrade to 1.22.3
  * libcupsfilters: Added error checks for processing GIF, to
    avoid crashes or hangs on broken GIF files (Issues #81, #82,
    Pull request #100).
  * cups-browsed: Added hint to the man page and configuration
    file that with "DebugLogging stderr" the logging output goes
    to journal or syslog if cups-browsed is running as system
    service (Issue #28).
- Version upgrade to 1.22.2
  * cups-browsed: Let distribution of jobs sent to queues with
    "implicitclass" backend (usually clusters) be done by a
    "job-state" CUPS notification and not by
    "printer-state-changed" any more. The "job-state"
    notification already contains the job ID. Before we had to
    poll the job ID from CUPS via IPP which was sometimes
    unreliable (Issue #97).
  * imagetopdf, imagetoraster, pdftopdf, libcupsfilters: Added
    new page scaling options: "fill" scales the input page
    (typically a photo) so that the output page (typically with
    different aspect ratio) gets completely filled, aloowing for
    some content of the input page getting lost. "crop-to-fit"
    allows for easy printing of documents on slightly different
    output page sizes (A4 <-> Letter) maintaining the size and
    centering and cropping into the destination page. Thanks to
    Dheeraj Yadav (dhirajyadav135 at gmail dot com) for the
    patch (Pull request #92).
  * cups-browsed: Do not do IPP request for printer-is-shared
    option for remote cups queues with CUPS 2.2.x and newer
    (Pull request #91).
  * cups-browsed: Fix crash bug when reading "Cluster"
    directive from configuration file (Issue #94).
  * driverless: Updated man page as now also Mopria and
    Wi-Fi Direct printers are supported. Mentioned also
    ippusbxd.
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 1.22.1:
  * braille: Use sort command with LC_ALL=C for reproducibility
    of the genrated files, needed for distribution packaging.
  * cups-browsed, driverless: When polling the printer's
    capabilities via get-printer-attributes IPP request for
    driverless printing, use the attributes "all" and
    "media-col-database". Without "all" some printers do not report
    "urf-supported" and without "media-col-database" not all paper
    size and marging info gets reported.
  * braille: Document how to rework output before embossing.
* Mon Jan 28 2019 bjorn.lie@gmail.com
- Update to version 1.22.0:
  * From this release on the pdftopdf filter flattens interactive
    PDF forms and annotations internally, using QPDF, instead of
    calling external utilities. This especially eliminates slowing
    factors as additional piping of the data and unneeded use of
    PDF interpreters. Using external utilities for flattening is
    still possible in case of problems. In addition, a crash bug in
    cups-browsed got fixed and compatibility of the filters with
    Poppler 0.72 assured.
- Drop upstream fixed patches:
  * 0001-Raise-minimum-poppler-version-from-0.18-to-0.19.patch
  * 0002-Adapt-code-for-SplashXPathScanner-state-handling-sin.patch
  * 0003-Support-some-more-methods-returning-const.patch
  * 0004-Support-GooString-c_str-introduced-by-poppler-0.72.patch
* Sat Dec 29 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix building with Poppler 0.72
  Add 0001-Raise-minimum-poppler-version-from-0.18-to-0.19.patch
  Add 0002-Adapt-code-for-SplashXPathScanner-state-handling-sin.patch
  Add 0003-Support-some-more-methods-returning-const.patch
  Add 0004-Support-GooString-c_str-introduced-by-poppler-0.72.patch
  See https://github.com/OpenPrinting/cups-filters/pull/83
* Tue Dec 18 2018 bjorn.lie@gmail.com
- Update to version 1.21.6:
  * Bug fix release, mainly for cups-browsed to avoid crashes and
    infinite printer removal/re-creation loops and spurious local
    queues for local CUPS printers. Also expanded PostScript
    interpreter bug workaround to more Apple LaserWriter models.
  * cups-browsed: To find out whether a DNS-SD-discovered printer
    is from the local machine, use not only the flags in the Avahi
    lookup result but also check the host name.
  * cups-browsed: When a local CUPS queue pointing to a remote CUPS
    printer was removed and re-created to make it a permanent
    queue, on_printer_deleted() was triggered by cupsd's
    notification to re-create a lost queue. Now
    on_printer_deleted() checks whether the queue is really gone
    and only re-creates then.
  * cups-browsed: When updating the CUPS queues, also removed and
    unregistered queues and not only created queues got checked for
    HTTP timeouts, which caused crashes on shutdown.
  * pdftops: Use the PS interpreter of Poppler for all Apple
    LaserWriter 16/600, 4/600, 12/640, 12/600, 12/660 as they all
    seem to not work with Ghostscript's PS output.
  * cups-browsed: On shutdown queues got removed even if they still
    had jobs.
- Changes from version 1.21.5:
  * Bug fix release, to build with Poppler 0.71 and with
    cups-browsed converting temporary CUPS queues reliably to
    permanent queues.
  * cups-browsed: We cannot reliably determine whether a CUPS queue
    is temporary, so we apply the procedure to make a temporary
    queue permanent to any unshared queue.
  * pdftoraster, pdftopdf, pdftoijs, pdftoopvp: Do not use the
    Poppler-specific "GBool", "gFalse", "gTrue" any more, as
    Poppler has switched to standard "bool", "false", "true" in
    version 0.71.0.
* Wed Nov 28 2018 bjorn.lie@gmail.com
- Update to version 1.21.4:
  * cups-browsed: cups-browsed: Limit the number of retries for
    creating a print queue when it comes to HTTP timeouts. Number
    of retries given by HttpMaxRetries directive in
    cups-browsed.conf.
  * cups-browsed: Read out current time right before setting the
    timeouts.
  * libcupsfilters: In the PPD generator for driverless IPP
    printing let "*cupsManualCopies: true" lines get added to
    the PPD if printing is done in a raster format as then
    pdftopdf needs to generate the copies.
  * pdftoraster, pdftoopvp, pdftoijs: Fix build with
    Poppler >= 0.70
  * pdftopdf: Fixed printing multiple copies on driverless IPP
    printers. When printing collated copies the multiple copies
    got applied twice, resulting in n*n instead of n copies.
  * pdftoraster, pdftoopvp, pdftoijs: Poppler removed memCheck
    and gMemReport functions, remove appropriate calls.
- Changes from version 1.21.3:
  * foomatic-rip: Reset stdin after replacing the underlying file
    descriptor.
- Changes from version 1.21.2:
  * cups-browsed: Fixed freeing of literal string caused by
    Coverity Scan issue fix.
* Thu Aug 30 2018 Tomáš Chvátal <tchvatal@suse.com>
- Do not diferentiate for service location, it is in sbindir
  on all systems we support now
- Use license for license install
- Version update to 1.21.1:
  - foomatic-rip: Fixed segmentation fault caused by wrong
    Coverity Scan issue fix (Issue #57, Debian bug #907026).
  - Build system: Require QPDF 8.1.0 or later as it is needed by
    bannertopdf (Issue #56).
  - libcupsfilters, cups-browsed, driverless, foomatic-rip,
    parallel: Silenced warnings from newest gcc.
  - libcupsfilters: When generating a PPD for driverless
    printing on a remote IPP printer, make pdftopdf not being
    run by the local queue if the remote queue is a CUPS queue
    to avoid running pdftopdf twice (CUPS Issue #5361).
  - libcupsfilters, cups-browsed, driverless, bannertopdf,
    foomatic-rip, pdftops, pdftoraster, rastertops,
    rastertoescpx, sys5ippprinter, beh: Fixed Coverity Scan
    issues. Thanks to Zdenek Dohnal (zdohnal at redhat dot com)
    for the tests and the patches.
  - bannertopdf: Switched over from using Poppler to using QPDF
    for generating the PDF pages. With Poppler unstable APIs
    were used which were subject to change. Thanks to Sahil
    Arora for this project in the Google Summer of Code 2018
    (Pull request #25).
  - cups-browsed: Manually defined clusters ("Cluster" directive
    in cups-browsed.conf) caused cups-browsed to crash.
* Tue Jul 17 2018 alarrosa@suse.com
- Version upgrade to 1.20.4
  - gstoraster: Removed unneeded "if"s (Ghostscript bug #692705).
  - cups-browsed: When checking whether there is already a local
    print queue with the same URI as the one of the discovered
    printer, consider also as equal URI if the URIs only differ
    by use of IPP or IPPS and/or use of HTTPS port 443 instead
    of IPP port 631.
  - cups-browsed: Also upgrade from ipp: to ipps: when the ipps:
    URI is on HTTPS port 443 instead of IPP port 631. This is
    common on IPP network printers.
  - pdftopdf: Removed support for hardware-implemented reversing
    of page order in PostScript printers. It was once not
    correctly implemented in cups-filters and second, such
    printers are extremely rare, and on Gutenprint PPDs with
    pseudo OutputOrder option hardware reversing was even
    wrongly assumed (Issue #47).
  - pdftopdf: Accept option "output-order=normal/reverse" for
    reversing page order (Issue #47) and also "page-delivery=
    same-order/reverse-order" (CUPS Issue #5340).
  - libcupsfilters: Let the PPD generator add "*PageStackOrder
    ..."  lines to the choices of the "OutputBin" option, to
    mark which output bins need the pages printed in reverse
    order (Issue #47).
  - libcupsfilters: Let the PPD generator correctly create a
    "*DefaultOutputOrder: ..."  entry, depending on whether the
    paper is put out face-up or face-down in the default output
    bin (Issue #47).
  - libcupsfilters: Fixed human-readable name of the OutputBin
    option in the PPD generator.
  - pdftoopvp: Silence compiler warning (Issue #42).
  - cups-browsed: If the user modifies/overwrites a print queue
    created by cups-browsed, it will now not only be
    automatically released from the control of cups-browsed, but
    we also create a replacement for our generated local queue
    under a new name.
  - cups-browsed: Make URIS for using the implicitclass backend
    correctly working also with queue names containing an '@'
    character.
  - braille: Strengthen error checking (Pull request #41).
  - braille: Index: Replace bogus characters with space (Pull
    request #41).
  - braille: Add print and braille page number options (Pull
    request #41).
  - braille: Index: Use standard duplex cups option (Pull
    request #41).
  - cups-browsed: Moved auto-generation of PPD file for IPP
    network printers from create_remote_printer_entry()
    function to update_cups_queues(). This allows re-creating
    accidentally removed or overwritten local queues without
    losing the PPD file.
  - braille: Add option to pick hyphenation rule according to
    current locale and make it the default for second
    translation table. (Pull request #38 and #39).
  - braille: Remove generated defs on "make clean". (Pull request #38).
  - braille: Turn non-breakable spaces to spaces. (Pull request
    [#38] and #39).
  - braille: Fix character encoding when extracting text. When
    extracing text from a zip file or a pdf, the resulting text
    is always utf-8 independently of the original locale, so we
    need to force that. (Pull request #38).
  - braille: Warn when no text translation was selected in case
    the user didn't notice. (Pull request #37).
  - braille: Fix spurious spacing after last Form-Feed (Pull
    request #45).
- Drop pdftoopvp_Silence-compiler-warning.patch
* Tue Jul 10 2018 bjorn.lie@gmail.com
- Add pdftoopvp_Silence-compiler-warning.patch: pdftoopvp: Silence
  compiler warning.
* Wed May  2 2018 luizluca@gmail.com
- Version upgrade to 1.20.3
  to fix regression from 1.20.2 that ignores printers published
  using legacy CUPS broadcast
* Tue Apr 10 2018 jsmeix@suse.de
- Version upgrade to 1.20.2
  to provide upstream bugfixes also for SLE15 / Leap15
  and be also already prepared for SLE12 (fate#323676).
  This is a bug fix release fixing the recognition
  of remote CUPS queues by cups-browsed, the behavior
  of cups-browsed when one creates a queue with the
  same name of a cups-browsed-generated queue overwriting
  it, and other bug fixes (for details see the NEWS file).
* Wed Apr  4 2018 jsmeix@suse.de
- Version upgrade to 1.20.1
  to provide upstream bugfixes also for SLE15 / Leap15
  and be also already prepared for SLE12 (fate#323676).
  This is a bug fix release fixing several issues
  on the Braille support and other bugs, in particular
  (for details see the NEWS file):
  * libcupsfilters: Silenced warning when using CUPS < 2.x
    by eliminating the use of a recently introduced
    CUPS library function, see
    https://bugs.linuxfoundation.org/show_bug.cgi?id=1421
  * cups-browsed: Fixed crash when CUPS reports a print queue
    without "device-uri" attribute when cups-browsed polls a
    list of local CUPS queues, see
    https://github.com/OpenPrinting/cups-filters/issues/16
- fix_upstream_bug_1421.patch is no longer needed because
  it is now fixed in the upstream sources
  (see the "libcupsfilters ... bug ... 1421" entry above).
* Wed Feb 21 2018 jsmeix@suse.de
- Version upgrade to 1.20.0:
  * Mainly enhancements and fixes for the PPD generator.
  * For detailed info see the NEWS file.
- fix_upstream_bug_1421.patch is the upstream fix for
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1421
- Use 'BuildRequires python3-cups' only if suse_version >= 1330
  (cf. "Do not require python-cups but rather python3-cups" below)
  which means after any SLE12 service pack and after any Leap 42.x
  i.e. for Tumbleweed, Leap 15.x, and the upcoming SLE15 and later
  otherwise still use 'BuildRequires python-cups' to make it build
  and usable again not only on some newest systems according to
  https://en.opensuse.org/openSUSE:How_to_contribute_to_the_Printing_project
* Tue Jan 23 2018 tchvatal@suse.com
- Version upgrade to 1.19.0:
  * See the detailed stuff in NEWS file
  * New filters and poppler compatibility as always
- Do not require python-cups but rather python3-cups in order to
  allow build on python2 less system
- Explicitly enable ijs and opvp filters
* Fri Sep 29 2017 olaf@aepfle.de
- Obsolete also debuginfo subpackages of the packages marked as
  Obsoletes in this specfile (bsc#1047897)
* Sat Sep 16 2017 zaitor@opensuse.org
- Version upgrade to 1.17.6:
  * As the changelog is long for detailed info check the NEWS file.
  * Package new filters.
  * Compatible with poppler 0.58 and newer (Bug #1408).
* Fri Jun  2 2017 jsmeix@suse.de
- The filter for Apple Raster input is rastertopdf
  for CUPS 2.2.2+ and urftopdf for older CUPS.
  Because Factory/Tumbleweed uses the newest CUPS for build
  (which is currently CUPS 2.2.3 as of this writing) the filter
  for Apple Raster input is rastertopdf for Factory/Tumbleweed
  so that /usr/lib/cups/filter/urftopdf must be excluded
  from the RPM files list for Factory/Tumbleweed.
* Thu Jun  1 2017 jsmeix@suse.de
- The RPM scriptlet hack that created a special cupsfilters.convs
  so that the gstoraster filter can be used with CUPS <= 1.5.4
  does no longer make sense and is therefore removed.
* Tue May 30 2017 jsmeix@suse.de
- Since version 1.14.0 there are no longer sub-packages
  (except cups-filters-devel) because nowadays cups-filters
  can no longer be built with CUPS < 1.6 with reasonable effort,
  see the entry below dated "Wed Oct  7 11:16:13 CEST 2015".
  On systems with CUPS >= 1.6 (i.e. since SLE12 GA / Leap 42.1)
  there is no good reason to keep cups-filters split into
  sub-packages and furthermore that split causes continuous
  (nowadays useless) efforts and bugs (like boo#1034877).
- Version upgrade to 1.14.0:
  Some excerpts (for details see the NEWS file):
  * cups-browsed: Added new setting "LocalOnly" for the
    CreateIPPPrinterQueues in cups-browsed.conf.
- Version upgrade to 1.13.5:
  Some excerpts (for details see the NEWS file):
  * foomatic-rip: When called via cupsfilter, foomatic-rip was
    not able to read the PPD file with (Bug #1388).
  * cups-browsed: When creating a local queue for a remote CUPS
    printer, add the line '*APRemoteQueueID: ""' to the PPD file
    so that CUPS sets the CUPS_PRINTER_REMOTE bit for the
    printer type of the local queue (Bug #1386).
- fallback_read_ppd_file_from_environment.patch is no longer
  needed because it is now provided in the upstream sources
  (see the "Bug #1388" entry above).
- Version upgrade to 1.13.4:
  Some excerpts (for details see the NEWS file):
  * cups-browsed: Corrected determination whether an IPP status
    is an error, to avoid "Unable to create/modify CUPS queue
    (Success)" and infinite repetition of a succeeded operation
    (Debian bug #852436).
* Mon Mar 13 2017 jsmeix@suse.de
- fallback_read_ppd_file_from_environment.patch
  lets foomatic-rip call read_ppd_file() with
  PPD filename from environment as fallback, see
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1388
* Fri Jan 20 2017 tchvatal@suse.com
- Version upgrade to 1.13.3:
  * As the changelog is long for detailed info check the NEWS file
  * Disable mutool switch to not build with mupdf package in order
    to not expand the dependencies too much
  * /usr/lib/cups/filter/textonly was renamed to texttotext
  * pstopdf filter dropped by upstream (cf. boo#1036220)
  * Add new driverless binary/driver to work with
    new style IPP printers that do not require any driver
* Thu Mar  3 2016 jsmeix@suse.de
- Version upgrade to 1.8.2
  * Allow disabling dependencies on Ghostscript and Foomatic
    (Bug #1342).
  * cups-browsed: Optionally generate also local queues pointing
    to remote raw queues. Usually only queues pointing to remote
    queues with PPD/driver are created (Debian bug #814020,
    Debian bug #756724).
- Version upgrade to 1.8.1
  * cups-browsed: Do not disable queues which still have jobs (and
    therefore cannot be removed) when avahi-daemon goes away, the
    print server is most probably still available and printing can
    be continued. Especially important on mobile devices where
    avahi-daemon is shut down when the print dialog is closed (and
  the job(s) still printing).
- Version upgrade to 1.8.0
  * COPYING: Replaced the COPYING file by a file in Debian format,
    derived from Debian's file but updated and corrected.
  * braille: Added info about additional packages needed for
    Braille printing to the README file.
  * braille: Let the Braille filters use lou_translate of
    liblouis if the more sophisticated file2brl of liblouisutdml
    is not installed. This is decided on at run time, so later
    installation of liblouisutdml will let the filters
    automatically switch to file2brl.
  * braille: Allow to build with Braille support also if
    liblouis is not installed at build time.
  * braille: Added checks for the presence of helper tools, to
    get clear messages in the CUPS error_log if something is
    missing.
  * Fixed copyright headers of files inherited from CUPS or
    derived from CUPS, pointing to COPYING as license info file,
    removing Apple exceptions, removing hints that a missing
    license info file can be found at www.cups.org, and removing
    "$Id" SVN file ID placeholders.
  * Updated COPYING file for missing implicitclass and beh
    backends.
- Version upgrade to 1.7.0
  * cups-browsed: Added possibility to trigger the auto shutdown
    by the queues of cups-browsed being without jobs. Before
    auto shutdown was only possible when all queues have gone
    away. This allows auto shutdown on mobile devices where
    avahi-daemon is also used for other things than printing.
- Version upgrade to 1.6.0
  * cups-browsed: Fixed use of CUPS domain socket, both
    detection during build process and permission check at
    runtime.
  * foomatic-rip: Fixed buffer overflow when reading environment
    variables CUPS_FONTPATH, CUPS_DATADIR, and GS_LIB (Bug
    [#1336]).
  * beh: Introduced beh, the Backend Error Handler, a wrapper
    backend to make handling of backend errors more
    configurable. This backend is a C re-write of the beh
    backend written in Perl which was part of the former
    foomatic-filters package. Several people asked for beh
    getting moved to cups-filters.
  * braille: Make image printing working also if ImageMagick
    generates formatted images without header.
  * braille: If the user does not select a Braille translation,
    let the embosser do the translation.
  * cups-browsed: Added version info to help screen and start-up
    in debug mode, call help screen also via "--version" option.
  * cups-browsed: Minor improvements in help screen and man page.
- Version upgrade to 1.5.0
  * cups-browsed: Allow use of an alternative configuration file
    via the "-c" command line option.
  * cups-browsed: Allow supplying configuration settings via the
    command line using the "-o" command line option.
  * cups-browsed: Command line help via the "-h" or "--help"
    command line option.
* Thu Dec 17 2015 jsmeix@suse.de
- Version upgrade to 1.4.0
  Changes in 1.4.0 (excerpt - for details see the NEWS file):
  * foomatic-rip: SECURITY FIX: Also consider the semicolon
    (';') as an illegal shell escape character. Thanks to Adam
    Chester (adam dot chester at pentest dot co dot uk) for the
    hint CVE-2015-8560 (bsc#957531).
  * brftoembosser, imagetobrf, imagetoubrl, imageubrltoindexv3,
    imageubrltoindexv4, textbrftoindexv3, textbrftoindexv4,
    texttobrf, braille.convs, braille.types, generic-brf.drv,
    indexv3.drv, indexv4.drv: Added support for Braille
    embossing via CUPS. Text and even images can now be sent to
    a Braille embosser like to a printer. Thanks to Samuel
    Thibault (samuel dot thibault at ens-lyon dot org) for this
    contribution.
- BuildRequires liblouis-devel is needed for Braille embossers.
- Version upgrade to 1.3.0
  Changes in 1.3.0 (excerpt - for details see the NEWS file):
  * cups-browsed: Added new BrowseFilter directive in
    cups-browsed.conf.  This directive allows filtering of the
    remote printers to be accepted on most properties/metadata
    supplied with the DNS-SD broadcasts. This allows, in
    addition to BrowseAllow/BrowseDeny/BrowseOrder, to reduce
    the amount of printers listed in print dialogs to a more
    useful amount.
  * cups-browsed: Added support for BrowseDeny and BrowseOrder
    directives in cups-browsed.conf.
  * cups-browsed: Let the BrowseAllow lines in cups-browsed.conf
    also apply to remote printers discovered via DNS-SD.
- Version upgrade to 1.2.0
  Changes in 1.2.0 (excerpt - for details see the NEWS file):
  * foomatic-rip: SECURITY FIX: Also consider the back tick
    ('`') as an illegal shell escape character. Thanks to Michal
    Kowalczyk from the Google Security Team for the hint
    CVE-2015-8327 (bsc#957531).
- Version upgrade to 1.1.0
  Changes in 1.1.0 (excerpt - for details see the NEWS file):
  * Version numbering scheme changed: Releases with feature
    addition/change have the minor number increased now, pure
    bug fix releases get the revision number increased, to make
    use of the minor number which stayed zero all the time.
  * cups-browsed: Added "DefaultOptions" directive to
    cups-browsed.conf to allow defining default option settings
    for local queues to be generated for newly appearing remote
    printers.
  * cups-browsed: Let option settings of a generated print queue
    be saved before taking the queue down so that when the remote
    printer appears again all user changes get restored, making
    user changes permanent on generated queues.
  * cups-browsed: Added a mode in which IP-based device URIs
    for the generation of local print queues are used, for
    cases with problems in local host name resolution.
  * foomatic-rip: Use -dFirstPage=... and -dLastPage=... only
    if really needed (Bug #1324).
  * cups-browsed, implicitclass: Make the load-balancing
    configurable so that one can select whether the jobs get
    queued up locally like in a CUPS class or whether they get
    immediately distributed to the remote servers letting them
    queue up there.
- FirstPage_LastPage_only_if_needed.patch is obsolete since
  version 1.1.0 because it is fixed in the sources.
* Wed Oct  7 2015 jsmeix@suse.de
- FirstPage_LastPage_only_if_needed.patch lets foomatic-rip
  add -dFirstPage=N [and -dLastPage=M] to the Ghostscript
  command line only if those options are actually needed
  (i.e. if FirstPage > 1 [and when LastPage >= FirstPage])
  cf. http://bugs.ghostscript.com/show_bug.cgi?id=696246
  and https://bugs.linuxfoundation.org/show_bug.cgi?id=1324
- At least for now support for cups154 in the SLE12 legacy module
  is abandoned (by default SLE12 has CUPS 1.7.5) because newer
  cups-filters versions again use stuff that is provided
  since CUPS > 1.5.4 so that it does no longer build with
  CUPS 1.5.4. Perhaps I (jsmeix@suse.de) find time to fix it
  again for CUPS 1.5.4 but when not, newer cups-filters will
  no longer work with CUPS 1.5.4.
- Version upgrade to 1.0.76
  Changes in 1.0.76 (excerpt - for details see the NEWS file):
  * cups-browsed, implicitclass: Let the load-balancing queue up
    the jobs in the local (generated) queue until a free (idle,
    enabled, and accepting jobs) remote queue is found (check
    every 5 sec if no free queue available). This gives a more
    even distribution of the work amongst the servers and
    protects against the case that a bunch of jobs gets
    inaccessible or lost if one of the servers fails.
  * cups-browsed: Let the load-balancing also check whether the
    destination queue is actually accepting jobs.
  * cups-browsed: If a generated queue is not removed on
    shutdown of cups-browsed due to remaining jobs in it,
    re-enable it in the next cups-browsed session even if it was
    disabled by something other than cups-browsed.
  * implicitclass: Clean up debug and error messages.
  * implicitclass: Fix exit codes for immediate retry of jobs.
  * cups-browsed: Make absence of CUPS notifications via D-Bus
    non-fatal and fall back to the old behavior of cups-browsed
    (fail-over instead of load balancing for equally-named
    remote queues, do not remove generated queue if it is
    default instead of default printer management). This solves
    problems of CUPS and/or cups-browsed built without D-Bus
    support or absence of D-Bus on the system (Bug #1316).
  * cups-browsed: Do not use g_warning() function, sneaked in
    by copy and paste of CUPS subscription functions.
- Version upgrade to 1.0.75
  Changes in 1.0.75 (excerpt - for details see the NEWS file):
  * texttopdf: Really support BoldItalic (original texttops
    just maps BoldItalic to Bold).
  * texttopdf: Fixed segfault when outputting BoldItalic
    (Bug #1314).
- Version upgrade to 1.0.74
  Changes in 1.0.74 (excerpt - for details see the NEWS file):
  * cups-browsed: Added NULL check when getting the notification
    of a printer starting to process a job and checking whether
    this printer is created by cups-browsed with the
    implicitclass: backend (Ubuntu bug #1488524).
  * cups-browsed: Do not schedule printers for update when they
    are already marked as disappeared.
  * cups-browsed: Added sanity checks when saving the default
    printer selection in a file.
  * cups-browsed, implicitclass: If remote queues disappear or
    cups-browsed shuts down and a cups-browsed-generated queue
    still has jobs and needs to be kept therefore, disable it
    and re-enable it when cups-browsed starts again and/or the
    remote queue(s) re-appear(s). This avoids repeated retries
    of the jobs while the remote server is not available, causing
    unneeded system load and battery consumption.
  * cups-browsed: After polling info from remote CUPS servers
    to find the best destination job, set the default CUPS server
    back to local.
- Version upgrade to 1.0.73
  Changes in 1.0.73 (excerpt - for details see the NEWS file):
  * cups-browsed: Added missing
    utils/org.cups.cupsd.Notifier.xml file.
- Version upgrade to 1.0.72
  Changes in 1.0.72 (excerpt - for details see the NEWS file):
  * cups-browsed, implicitclass: Added load balancing
    functionality. If there are several remote CUPS printers
    with the same name, they for locally a cluster represented
    by a print queue with this name. This printer prints through
    a special backend (implicitclass) which makes cups-browsed
    find the best destination remote queue (fewest jobs,
    enabled) for this job.
  * cups-browsed: Added protection against accidental deletion of
    print queues generated by cups-browsed. These queues now get
    automatically re-created.
  * cups-browsed: Added LDAP support. Appropriately configured
    via cups-browsed.conf remote printers made available via LDAP
    will be looked up and local queues pointing to them created.
    Thanks to Raphael Geissert (atomo64 at gmail dot com) for
    contributing this patch (Debian bug #795185).
  * cups-browsed: Introduced new handling for the default printer
    using cache files. So we do not need to keep an auto-generated
    queue because it is set as default printer. If the
    auto-generated queue disappears, the old local printer is set
    as default again and when it re-appears it returns to be the
    default printer.
  * cups-browsed: Added infrastructure for subscribing to CUPS
    notifications for things like improved default printer
    handling, load balancing, ...
  * foomatic-rip: Prevent crash when supplying "media" option with
    empty value ("media=", Ubuntu bug #1479871).
  * pdftoopvp: Adaptations to API changes on Poppler 0.34.0, note
    that this patch disables color management in this filter.
    Thanks to Vincent le Garrec and Andreas K. Huettel for the
    patch (Bug #1301, Gentoo bug #554782).
  * texttopdf: Request the generic 'monospace' font alias from
    fontconfig instead of the hard-coded FreeMono. Thanks
    to Fabian Greffrath (fabian at debian dot org) for the
    patch (Debian bug #788048).
- cups-filters-poppler-034.patch is obsolete since version 1.0.72
  because it is fixed in the sources.
* Thu Sep  3 2015 jsmeix@suse.de
- More appropriate URL entry in spec file:
  Now it is (wrapped URL)
  http://www.linuxfoundation.org/collaborate/workgroups
    /openprinting/cups-filters
  that shows mainly generic information instead of (wrapped URL)
  http://www.linuxfoundation.org/collaborate/workgroups
    /openprinting/pdf_as_standard_print_job_format
  that provides mainly technical details.
* Sun Jul 26 2015 zaitor@opensuse.org
- Add cups-filters-poppler-034.patch: Fix build with poppler-0.34.
  See https://bugs.linuxfoundation.org/show_bug.cgi?id=1301
  pdftoopvp: Adaptations to API changes on Poppler 0.34.0, note
  that this patch disables color management in this filter.
* Mon Jul  6 2015 jsmeix@suse.de
- Version upgrade to 1.0.71
  Changes in 1.0.71 (cf. the NEWS file but there is a typo
  in the NEWS file that claims the CVE number is 3259
  while the correct CVE number is 3279):
  * texttopdf: The Page allocation is moved into textcommon.c,
    where it does all the necessary checking:
    lower-bounds for CVE-2015-3258 (bsc#936281) and
    upper-bounds for CVE-2015-3279 (bsc#937018)
    due to integer overflows for the calloc() call
    initialising Page[0] and the memset() call in texttopdf.c's
    WritePage() function zeroing the entire array.
    Thanks to Tim Waugh from Red Hat for the patch.
  * texttopdf: Upper-bounds checking CVE-2015-3279 (bsc#937018).
* Mon Jun 29 2015 jsmeix@suse.de
- Version upgrade to 1.0.70
  Changes in 1.0.70 (excerpt - for details see the NEWS file):
  * texttopdf: Fixed buffer overflow on size allocation
    of texttopdf when working with extremely small line sizes,
    which causes the size calculation to result in 0
    CVE-2015-3258 (bsc#936281), thanks to Stefan Cornelius
    from Red Hat for the patch.
  * cups-browsed: leak fixes
  * cups-browsed: Further BrowseAllow fixing
  * cups-browsed: BrowsePoll is an array of pointers,
    not structures, so allocate room for the pointers
  * cups-browsed: Prevent NULL dereference when handling
    BrowseAllow without value
  * cups-browsed: Use memory deallocation function
    corresponding to allocation function used
  * cups-browsed: Fixes for glib source handling
    (Red Hat bug #1228555)
- Version upgrade to 1.0.69
  Changes in 1.0.69 (excerpt - for details see the NEWS file):
  * cups-browsed: When checking whether a queue name already
    exists as a locally defined queue, do case-insensitive
    comparing as for CUPS printer names are case-insensitive.
    This assures that already existing queues do never get
    overwritten.
  * cups-browsed: Added "IPPPrinterQueueType Auto/PPD/NoPPD"
    directive to cups-browsed.conf to allow controlling how
    cups-browsed creates queues fr native IPP network printers:
    with PPD, with System V interface script, or selecting
    automatically.
  * pdftopdf: Center Landscape-oriented jobs correctly
    on the page if the "fitplot" or "number-up" options
    are used (Bug #1284).
  * pstopdf: Removed "-dUseCIEColor" from the Ghostscript command
    line. In modern Ghostscript versions (9.11 and newer) it is
    recommended to not use it with the pdfwrite and ps2write
    output devices any more.
  * imagetopdf: Corrections in PDF output: Let evince display
    the PDF with the correct size including margins and let
    ghostscript not complain about an invalid xref entry.
  * sys5ippprinter: Renamed pdftoippprinter to reflect that it is
    once a System 5 interface script and second does not accept
    only PDF as input.
  * pdftoippprinter: Support also PWG Raster and JPEG as input
    formats so that an auto-generated, PPD-less queue for an
    IPP printer emulates an IPP Everywhere printer.
* Thu May 14 2015 tchvatal@suse.com
- Version bump to 1.0.68:
  * cups-browsed: Numeric IDs for GSources of the glib event
    loop must be positive integers greater than zero according
    to the documentation of the g_source_get_id() function.
    Taken care of this at all places.
  * cups-browsed: Added conditionals so that it also builds with
    CUPS 1.5.x (but then withou support for automatically creating
    queues for IPP network printers). Thanks to Johannes Meixner
    from SUSE for the patch (Bug #1268).
  * Ricoh-PDF_Printer-PDF.ppd: Added PPD file for Ricoh's PDF
    printers (experimental). Thanks to Ulrich Wehner from Ricoh
    for the file.
- Remove upstream merged patch:
  * fix-create_local_queue-ifndef-HAVE_CUPS_1_6.diff
* Fri Mar 20 2015 jsmeix@suse.de
- For SLE12 build it with traditional CUPS 1.5.4 to ensure
  it works on SLE12 both with CUPS 1.7.5 and CUPS 1.5.4.
* Fri Mar 20 2015 jsmeix@suse.de
- fix-create_local_queue-ifndef-HAVE_CUPS_1_6.diff
  makes it compile again without errors also for CUPS <= 1.5.4
  by excluding code that uses CUPS >= 1.6 specific stuff,
  in particular by skipping create_local_queue for non-CUPS
  printer broadcasts for CUPS <= 1.5.4, see the upstream bug
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1268
* Thu Mar 12 2015 tchvatal@suse.com
- Reenable threads, seems to work fine. If there are thread
  related issues assign the bug to me.
* Thu Mar 12 2015 jsmeix@suse.de
- Version upgrade to 1.0.67
  Changes in 1.0.67:
  * cups-browsed: Use g_source_remove() instead of
    g_source_destroy() for killing auto shutdown timers
    (Ubuntu bug #1427344).
* Sat Mar  7 2015 tchvatal@suse.com
- Do no longer create foomatic-rip symlink that is now done
  by make install command (see linuxfoundation.org bug #1255
  and the entry dated "Mon Aug 25 15:30:37 CEST 2014" below).
- Fix postun call on cups-browsed to call right rpm macro
* Sat Mar  7 2015 tchvatal@suse.com
- Version bump to 1.0.66:
  * Many fixes in cups-browsed in particular a SECURITY FIX:
    Fixed a bug in the remove_bad_chars() failing to reliably
    filter out illegal characters if there are two or more
    subsequent illegal characters, allowing execution of arbitrary
    commands with the rights of the "lp" user, using forged print
    service announcements on DNS-SD servers
    (CVE-2015-2265, boo#921753, linuxfoundation.org bug #1265).
  * Compat code for new poppler.
  * For detailed listing see NEWS file in documentation.
- Use .xz for tarball, bit smaller, adds dep on xz, no biggie
- Changes in verion 1.0.63 (excerpts):
  * foomatic-rip: Added hint to man page that direct,
    spooler-less mode is mainly for testing and debugging
    (linuxfoundation.org bug #1253, bsc#915545)
  * foomatic-rip: Added a symlink of the filter to the
    binary executable directory (usually /usr/bin),
    so that LSB compliance test scripts work
    (linuxfoundation.org bug #1255, bsc#915545).
* Mon Nov 10 2014 jsmeix@suse.de
- During installation of a whole openSUSE system
  cups-filters-ghostscript can be installed before cups
  and then there is no /usr/share/cups/mime/ directory
  so that it is created if needed (bnc#904652).
* Mon Aug 25 2014 jsmeix@suse.de
- A /usr/bin/foomatic-rip -> /usr/lib/cups/filter/foomatic-rip
  symlink is added to the cups-filters-foomatic-rip sub-package
  to make our lsb RPM installable again (bnc#892604).
  LSB currently requires /usr/bin/foomatic-rip but future LSB
  will require /usr/lib/cups/filter/foomatic-rip see
  https://lsbbugs.linuxfoundation.org/show_bug.cgi?id=3900
* Mon Aug 25 2014 jsmeix@suse.de
- Version upgrade to 1.0.58
  Changes in 1.0.58 (excerpt - for details see the NEWS file):
  * pdftoraster: Changed ICC profile get function to accept a
    PPD fallback profile.
  * pdftoraster: Fixed handling of cupsColorSpaces 18,19,20.
  * rastertopdf: Grayscale color conversion now properly inverts
    bits.
  * rastertopdf: Implemented basic 8bit->8bit color space
    conversions.
  * rastertopdf: Added black point compensation.
  * rastertopdf: Added handling of color rendering intent.
  * gstoraster, imagetoraster, pdftoraster, rastertopclx,
    rastertopdf, foomatic-rip: Use color management functions in
    libcupsfilters.
  * libcupsfilters: Modified code formatting and documentation in
    the color management functions.
  * libcupsfilters: Fixed string handling and added debug log
    messages in the color management functions.
  * libcupsfilters: Fixed Adobe RGB matrix for proper rendering
    (transpose)
  * libcupsfilters: Moved color management functions from the
    individual filters to the libcupsfilters library.
- Version upgrade to 1.0.57
  Changes in 1.0.57 (excerpt - for details see the NEWS file):
  * Build system: Explicitly link to libm as -lm was dropped
    from cups-config --libs.
  * libcupsfilters, foomaticrip, gstoraster, imagetoraster,
    pdftoraster, rastertopclx, rastertopdf: Handle absence of
    colord or D-Bus gracefully (Ubuntu bug #1356405).
- Version upgrade to 1.0.56
  Changes in 1.0.56 (excerpt - for details see the NEWS file):
  * Major regression fix in cups-browsed (introduced in 1.0.55
    by no longer creating a local queue pointing to a remote
    raw queue that causes no longer creating local queues for
    traditional CUPS Browsing remote CUPS queues):
    Do not consider a remote CUPS queue as raw if the TXT record
    is NULL as for queues broadcasted by the legacy CUPS method
    the TXT record does not exist. Now  consider a queue with
    NULL TXT record only as raw if the domain entry is not empty
    which tells that the queue is Bonjour-broadcasted
    (linuxfoundation.org bug #1223).
  * cups-browsed: Do also not mark a discovered printer as
    already provided by another server when the other server's
    queue has "unconfirmed" status. Mark the other queue with
    "disappeared" or "unconfirmed" status as duplicate of the
    discovered printer so that the new queue for the discovered
    printer does not get removed when the entry for the other
    queue times out.
  * rastertopdf: Some code polishing and removal of now unneeded
    functions
  * rastertopdf: Reduced color space handling to only
    PWG-supported color spaces
  * rastertopdf: Added colorspace calibration function; included
    optional "/Alternate" PDF key for ICC profile embedding
  * rastertopdf: Colorspace sRGB now embeds srgb icc profile;
    implemented ICC Profile embedding (PDF 1.3 spec)
  * rastertopdf: Added basic color calibration
  * rastertopdf: Implemented ICC Profile creation code for IPP
    Everywhere (from PWG raster)
  * pdftoraster: Added colord handling of ICC profiles
* Wed Jul 30 2014 jsmeix@suse.de
- Version upgrade to 1.0.55
  Changes in 1.0.55 (excerpt - for details see the NEWS file):
  * pdftopdf: Fixed manual duplex by adding a blank page to even
    pages if the total number of pages of the document is odd.
    Otherwise the last page of the document would stay in
    the input tray. This fixes also a side effect as the set of
    even pages reducing to a zero page job if the job consists
    of only one page, making Poppler's pdftops error out
    (Ubuntu bug #1340435).
  * cups-browsed: Do not mark a discovered printer as already
    provided by another server when the other server's queue has
    "disappeared" status. This queue can be from the same server
    before it changed its name.
  * cups-browsed: Do not create a local queue pointing to a
    remote raw queue (Ubuntu bug #1335211).
  * foomatic-rip, imagetoraster, pdftoraster, rastertopclx,
    rastertopdf: Added colord "device_inhibit" support for
    color-managed filters.
  * bannertopdf: Fixed "Printer Location" and "Driver Version"
    entries on test page/banners (linuxfoundation.org bug #1209).
  * bannertopdf: Added new PDF template files which contain the
    text strings appropriate to the banners, before the banners
    were all equal, without text (linuxfoundation.org bug #1209).
  * pstopdf: Use "grep -E" instead of "grep -P" as the latter
    generates executable code and executes it, requiring
    "execmem" privileges which could be not available in some
    security policies. Thanks to Tim Waugh from Red Hat for the
    patch (Red Hat bug #1079534).
  * pdftoraster: Fixed segfault caused by introduction of
    "no-color-management" option (linuxfoundation.org bug #1214).
  * libcupsfilters: Let cupsRasterParseIPPOptions() also accept
    "pwg-raster-document-type" settings with hyphen between
    color space name and color depth.
- Our separated source files classified.pdf confidential.pdf
  secret.pdf standard.pdf topsecret.pdf unclassified.pdf (see
  the entry below dated "Thu Jun 12 17:27:56 CEST 2014") are
  no longer needed because it is now provided in the upstream
  sources (see "linuxfoundation.org bug #1209" entries above).
- Added CVE-2014-4336 CVE-2014-4337 bnc#883543 and
  CVE-2014-4338 bnc#883536 to the matching entry below
  dated "Mon Apr 28 10:49:21 CEST 2014" because those CVEs
  and bncs have not been known at that time (cf. bnc#871327
  therein comment#47 and bnc#883307 therein comment#2).
* Thu Jun 12 2014 jsmeix@suse.de
- Have different header texts for the PDF-BANNER printouts
  (same headers as on the CUPS <= 1.5.4 banner pages):
  Provide PDF template files classified.pdf confidential.pdf
  secret.pdf standard.pdf topsecret.pdf unclassified.pdf and
  modify the matching /usr/share/cups/banners/ template files
  accordingly to use those PDF templates
  (see https://bugs.linuxfoundation.org/show_bug.cgi?id=1209).
* Wed Jun 11 2014 jsmeix@suse.de
- Version upgrade to 1.0.54
  Changes in 1.0.54 (excerpt):
  * pdftoraster: Support for output in the color spaces 18
    (CUPS_CSPACE_SW, sGray), 19 (CUPS_CSPACE_SRGB, sRGB), and 20
    (CUPS_CSPACE_ADOBERGB, Adobe RGB). No color management
    appropriate to these color spaces is added yet.
  * rastertopdf: Added new filter to convert PWG Raster input
    into a PDF file (using QPDF). This filter makes CUPS
    supporting the PWG Raster input format which is required to
    be supported by IPP Everywhere printers, making a shared
    CUPS queue emulating an IPP Everywhere printer. This is a
    first implementation which supports the black, RGB, CMYK,
    sGray, sRGB, and Adobe RGB color spaces (all mapped to
    DeviceGray, DeviceRGB, and DeviceCMYK resp. in the PDF
    output) with 1, 8, and 16 bits per component color
    depth. sGray, sRGB, and Adobe RGB are currently also mapped
    to DeviceGray and DeviceRGB and do not have the correct
    color management yet, so color output is not absolutely
    correct. Note that mime.types of CUPS up to 1.7.2 has a bug
    which prevents PWG Raster to be recognized, the
    "priority(100)" of the rule needs to be changed to
    "priority(150)".
  * cups-browsed: Create local queues also to access classes on
    remote CUPS servers (Ubuntu bug #1313741).
  * cups-browsed: Let a newly discovered printer not only
    overtaking an existing printer entry if it is from the same
    host (usually IPP -> IPPS) or without host entry
    (unconfirmed local queue from previous cups-browsed session)
    but also if it is marked disappeared. So printer entries get
    correctly migrated when things like a host name change of
    the remote server happen.
  * cups-browsed: Always do case-insensitive comparing of
    strings, as CUPS queue names and URIs are case-insensitive
    (CUPS STR #4411).
  For details see the NEWS file.
* Mon Apr 28 2014 jsmeix@suse.de
- Version upgrade to 1.0.53
  Changes in 1.0.53:
  * foomatic-rip: Fixed segfault when creating log file, see
    https://bugs.linuxfoundation.org/show_bug.cgi?id=1206
  * cups-browsed: SECURITY FIX: Fix on usage of the
    "BrowseAllow" directive in cups-browsed.conf. Before, if the
    argument of a "BrowseAllow" directive is not understood it
    is treated as the directive not having been there, allowing
    any host if this was the only "BrowseAllow" directive. Now
    we treat this as a directive which no host can fulfill, not
    allowing any host if it was the only one. No "BrowseAllow"
    directive means access for all, as before, see
    https://bugs.linuxfoundation.org/show_bug.cgi?id=1204
    (CVE-2014-4338 bnc#883536 and bnc#871327 therein comment#23
    and subsequent comments).
  * cups-browsed: SECURITY FIX: Further improvement on the fix
    in 1.0.51 as it was insufficient. In addition, some fixes
    against OOB access are done (CVE-2014-4336 CVE-2014-4337
    bnc#883543 and bnc#871327 therein comment#30 and subsequent
    comments).
- Removed the "# BrowseAllow cups.example.com" example line in
  /etc/cups/cups-browsed.conf because hostnames do not work, see
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1205
* Thu Apr 24 2014 jsmeix@suse.de
- Split cups-browsed into a cups-filters-cups-browsed sub-package
  so that cups-browsed can be installed without all the other
  stuff from cups-filters (bnc#873204).
- Have libcupsfilters.so.* in the cups-filters-ghostscript
  sub-package because gstoraster is linked with libcupsfilters
  so that now cups-filters-foomatic-rip requires
  cups-filters-ghostscript which is still o.k. because
  cups-filters-ghostscript does not require cups-filters
  (cf. the entry dated "Thu Apr 10 10:22:25 CEST 2014" below).
- Do no longer rename installed /usr/share/cups/banners/* files
  and the installed /usr/share/cups/data/testprint
  (cf. the entry dated "Fri Aug 30 12:53:57 CEST 2013" below)
  because since CUPS 1.7.2 those files are no longer provided
  in our cups RPM package because since CUPS >= 1.6
  the CUPS banners and testprint do no longer work because
  there is no longer a filter for Linux that can convert
  the CUPS banner files. Since CUPS >= 1.6 only the banners
  and testprint in cups-filters work (bnc#873376).
  For CUPS <= 1.5.4 (where CUPS banners and testprint works)
  this does not make a difference because the cups-filters
  main package conflicts with CUPS <= 1.5.4.
* Thu Apr 10 2014 jsmeix@suse.de
- Have libcupsfilters.so.* in the cups-filters-foomatic-rip
  sub-package because foomatic-rip is linked with libcupsfilters
  so that it must be in the cups-filters-foomatic-rip sub-package
  to ensure the cups-filters-foomatic-rip sub-package can be
  installed on its own without a RPM requirement for the
  cups-filters main package which would cause conflicts
  with CUPS <= 1.5.4 in particular when building packages
  with CUPS <= 1.5.4 that have foomatic-rip as build requirement
  (e.g. hplip via "BuildRequires: foomatic-filters").
* Tue Apr  8 2014 jsmeix@suse.de
- Version upgrade to 1.0.52
  Changes in 1.0.52 (excerpt):
  * texttopdf, imagetopdf, imagetoraster:
    Range-check paper dimensions and margins taken
    from the PPD file and correct them if needed, see
    https://bugs.linuxfoundation.org/show_bug.cgi?id=1195
* Thu Apr  3 2014 jsmeix@suse.de
- Version upgrade to 1.0.51
  * cups-browsed: SECURITY FIX to prevent arbitrary code
    injection into the System V interface scripts generated for
    queues for discovered native IPP printers by a malicious IPP
    print service with forged make/model and/or PDL string
    (CVE-2014-2707 bnc#871327).
- Version upgrade to 1.0.50
  Changes in 1.0.50 (excerpt):
  * pdftops: Let old HP LaserJet printers (model number without
    letter, like "LaserJet 3" or "LaserJet 4000") use Poppler
    instead of Ghostscript.
  * pdftops: Improved workaround for Toshiba printers. Instead
    of using Poppler do not emit TrueType fonts with Ghostscript.
* Thu Mar 27 2014 jsmeix@suse.de
- Provide foomatic-filters with the exact foomatic-rip version
  that is included in cups-filters and conflict with any other
  foomatic-filters version (bnc#870621).
* Wed Mar 26 2014 jsmeix@suse.de
- Upgrade to current tarball cups-filters-1.0-20140326.tar.gz
  that is is version 1.0.49 plus the fix for
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1187
  "percent-encode component parts of the CUPS device-URI"
  see also (bnc#869692).
- Prepare spec files to build both releases and current tarballs
  easily in the future by using special different version strings.
* Tue Mar 25 2014 jsmeix@suse.de
- Version upgrade to 1.0.49
  Changes in 1.0.49 (excerpt):
  * pdftops: Fixed typo which always made PostScript level 2 being
    generated when using Poppler's pdftops.
  Changes in 1.0.48 (excerpt):
  * cups-browsed: Fix for a crash which happens on Bonjour reports
    of printers without "product", "usb_MDL", and "ty" fields
  Changes in 1.0.47 (excerpt):
  * pdftoopvp: SECURITY FIX for CVE-2013-6474, CVE-2013-6475,
    and CVE-2013-6476: Introductionof gmallocn and gmallocn3
    to protect against arbitrary code execution with the
    privileges of the "lp" user via malicious PDF files. Also
    restrict the directory from where OPVP drivers can get
    loaded.
  * urftopdf: SECURITY FIX for CVE-2013-6473: Two heap-based
    buffer overflow flaws in urftopdf. If a malicious URF file
    were processed it could lead to arbitrary code execution
    with the privileges of the "lp" user.
  * cups-browsed: Check for changes of the URI of a queue which
    we have created and correct the URI if needed
  Changes in 1.0.46 (excerpt):
  * gstoraster: Ignore SIGCHLD, rely on waitpid instead and
    fix two instances of insufficient EINTR handling.
  Changes in 1.0.45 (excerpt):
  * cups-browsed: Added auto-shutdown feature for on-demand use
    of cups-browsed (for example on mobile devices). With auto
    shutdown active, cups-browsed terminates after a certain
    time interval (30 sec by default) without having any remote
    printer to make available locally. The mode can be turned
    on, turned off (default) or set to automatically be off
    while avahi-daemon is running an on otherwise (controlled by
    avahi-daemon running on-demand). The mode and the timeout
    interval can be selected by command line options, the
    configuration file, and sending signals to cups-browsed
    (on/off only).
  * cups-browsed: To make Bonjour-discovered printers locally
    available avahi-daemon does not need to be started before
    cups-browsed and does not need to stay continuously running
    while cups-browsed is running. Bonjour-discovered printers
    are now added whenever avahi-daemon starts and removed
    whenever avahi-daemon stops and cups-browsed keeps running.
  * pdftops: Log command lines of renderer (Ghostscript, pdftops,
    pdftocairo, acroread) and of pstops in CUPS' error_log (in
    debug mode).
  Changes in 1.0.44 (excerpt):
  * README: Documented the "hybrid" choice for the PDF renderer
    in the pdftops filter.
  Changes in 1.0.43 (excerpt):
  * cups-browsed: When automatically setting up a PPD-less print
    queue for an IPP network printer add make/model info as an
    additional "make-and-model" command line option to the call
    of the pdftoippprinter filter, this way filters can do
    make/model-specific exceptions.
  * pdftops: Ignore "landscape", "orientation-requested",
    "fit-to-page", and any page geometry options. The first two
    do not make sense on PDF input and therefore should only be
    used in ...topdf filters used before pdftopdf, the others
    are already taken care of by pdftopdf so that pdftops gets
    pages with print-ready page geometry.
  * pdftopdf: If there is no PPD file or no
    "*LandscapeOrientation:" keyword in the PPD file, rotate
    counterclockwise, not clockwise to fit a landscape-oriented
    page on a portrait-oriented sheet.
  * pstopdf: Support for the "landscape" and
    "orientation-requested" options.
  * pdftops: After fixing the output of rotated PDF pages
    (usually landscape-oriented pages rotated by pdftopdf) in
    Poppler (Poppler/freedesktop.org bug #72312) corrected the
    use of "pdftops -origpagesizes" in pdftops appropriately.
  Changes in 1.0.42 (excerpt):
  * pdftoraster: Take into account rotate field in PDF header,
    when pdftopdf rotates a page to fit the paper it sets the
    rotate field and does not swap the width and height entries.
  * cups-browsed: Fixed several memory leaks by adding missing
    free() calls and removing an unneeded strdup().
  * foomatic-rip: Moved foomatic-rip's upstream home from the
    foomatic-filters package to cups-filters, to make it easier
    for distributions to ship and maintain a complete printing
    stack and also to make upstream maintenance and development
    easier.
  * foomatic-rip: Removed support for all the non-CUPS printing
    environments as they are discontinued upstream. Now
    foomatic-rip only works as a CUPS filter and in a
    spooler-less direct mode, where the latter is mainly
    for testing and debugging.
  Changes in 1.0.41 (excerpt):
  * cups-browsed: Added support for automatic PPD-less setup of
    print queues for IPP printers discovered on the network via
    Bonjour. Supported are printers with known languages (PWG
    Raster, PDF, PostScript, PCL XL, PCL 5c/e), especially also
    IPP Everywhere printers. This functionality is especially
    ment for mobile devices to be able to print without printer
    setup tool and without printer driver/PPD collection.
  * pdftoippprinter: New filter for PPD-less printing. The filter
    will be configured as System-V interface script for a print
    queue for a discovered IPP network printer generated by
    cups-browsed.
  * cups-browsed: Fixed socket leaks in recent IPP subscriptions
    changes.
- Since cups-filters version 1.0.42 foomatic-rip is also
  provided by cups-filters so that there is a file conflict
  with the foomatic-filters package (both provide
  /usr/lib/cups/filter/foomatic-rip and
  /usr/share/man/man1/foomatic-rip). Therefore foomatic-rip
  is separated in the sub-package cups-filters-foomatic-rip
  and only that sub-package conflicts with foomatic-filters.
* Thu Mar 13 2014 jsmeix@suse.de
- Added "Recommends: poppler-tools" because /usr/bin/pdftops
  (provided by poppler-tools) is needed (but not required
  for non-PostScript printers) to print PDFs on PostScript
  printers (bnc#868148).
* Thu Jan 30 2014 jsmeix@suse.de
- Moved /usr/lib/libcupsfilters.so /usr/lib/libcupsfilters.so
  /usr/lib/pkgconfig/libcupsfilters.pc /usr/include/fontembed/*
  /usr/lib/pkgconfig/libfontembed.pc /usr/include/cupsfilters/*
  to the cups-filters-devel sub-package to fix rpmlint
  "devel-file-in-non-devel-package" errors.
* Fri Jan 10 2014 jsmeix@suse.de
- Split /usr/share/cups/ppdc/escp.h and /usr/share/cups/ppdc/pcl.h
  into a cups-filters-devel sub-package and let cups-filters-devel
  conflict with cups-devel < 1.6. because up to CUPS 1.5.4
  those files are provided by the cups-devel package
  (see the next entry below).
* Thu Jan  9 2014 jsmeix@suse.de
- Conflict with CUPS < 1.6 because up to CUPS 1.5.4
  the following files are provided by the cups binary RPM package
  /usr/lib/cups/filter/commandtoescpx
  /usr/lib/cups/filter/commandtopclx
  /usr/lib/cups/filter/imagetops
  /usr/lib/cups/filter/imagetoraster
  /usr/lib/cups/filter/pdftops
  /usr/lib/cups/filter/rastertoescpx
  /usr/lib/cups/filter/rastertopclx
  /usr/lib/cups/filter/texttops
  /usr/lib/cups/backend/parallel
  /usr/lib/cups/backend/serial
  and the following files are provided by the cups-devel package
  /usr/share/cups/ppdc/escp.h
  /usr/share/cups/ppdc/pcl.h
* Thu Dec 19 2013 jsmeix@suse.de
- Split binary RPM sub-package cups-filters-ghostscript
  which is needed for Ghostscript version upgrade to 9.10.
  Since Ghostscript version 9.10 the CUPS filters
  gstoraster and gstopxl are removed from Ghostscript.
  Those filters are now provided by cups-filters.
  The binary RPM sub-package cups-filters-ghostscript
  provides only those CUPS filters for Ghostscript.
  This way cups-filters-ghostscript can be used
  with the traditional CUPS up to version 1.5.4
  where the other filters, backends, and cups-browsed
  from cups-filters would cause conflicts because
  CUPS <= 1.5.4 already provides them. In contrast
  for CUPS versions since 1.6 the whole cups-filters
  is usually needed (but not strictly required).
* Wed Oct 30 2013 jsmeix@suse.de
- Version upgrade to 1.0.40
  Changes in 1.0.40 (excerpt):
  * pdftops: Introduced new "hybrid" renderer: Here usually
    Ghostscript is used, but if the printer is a Brother,
    Minolta, or Konica Minolta Poppler's pdftops gets used. This
    is a quirk rule to work around bugs in the PS interpreters
    of the printers.
  Changes in 1.0.39 (excerpt):
  * pdftops: Fix for landscape PDF handling.
  Changes in 1.0.38 (excerpt):
  * pdftops: Added "-dNOINTERPOLATE" to the Ghostscript command
    line for quicker processing of embedded bitmaps.
  * pstopdf: Added "-dUseCIEColor" to the Ghostscript command
    line to assure compatibility with newer Ghostscript
    versions (9.08 and newer).
  Changes in 1.0.37 (excerpt):
  * Added example configuration files for systemd and Upstart, see
    https://bugzilla.novell.com/show_bug.cgi?id=735404#c46
    (obsoletes cups-browsed.service).
  * Build system: Make sure that gstoraster gets linked against
    the libcupsfilters of the currently built package and not
    of the system (obsoletes broken-autotools.patch).
  * cupsfilters.convs: Reworked the cost factors of the filters
    to avoid bogus filter chains like pstotiff|imagetopdf
    instead of pstopdf|pdftopdf for PostScript->PDF, see
    https://bugzilla.novell.com/show_bug.cgi?id=735404#c53
  * cups-browsed: Fixed building with CUPS 1.5.x and older,
    ippSetVersion() was missing under the accessor function
    definitions for backward compatibility
    (obsoletes cups-15-compat.patch).
  For details see the NEWS and README files.
- cups-browsed.service is obsolete (provided in upstream sources).
- broken-autotools.patch is obsolete (fixed in upstream sources).
- cups-15-compat.patch is obsolete (fixed in upstream sources).
* Fri Aug 30 2013 jsmeix@suse.de
- Rename installed /usr/share/cups/banners/* files
  and the installed /usr/share/cups/data/testprint
  because those files are also provided by CUPS
  but CUPS provides them in a different format and
  I not want to overwrite CUPS files but I do not like
  to delete the cups-filters version of those files
  instead I like to provide them at least for now as well
  so that we could evaluate which ones we may use finally.
* Wed Aug 21 2013 tchvatal@suse.com
- Version bump to 1.0.36:
  * new manpages
  * many small adjustments see NEWS
- Remove obsolete patch fix_cups-browsed_init_script.patch
- Remove obsolete patch BZR_revision_7085_7084.diff
- Add new patch to compat with old cups cups-15-compat.patch
- Add new patch to fix borked autotools broken-autotools.patch
- Adjust the service call for older distros it was in /sbin
- Enable tests
* Fri Aug  2 2013 jsmeix@suse.de
- Added support for systemd (mainly done by tchvatal@suse.com).
  cups-browsed.service is openSUSE's systemd unit file.
  Nevertheless a traditional SysVInit script
  /etc/init.d/cups-browsed is still available.
* Tue Jul 30 2013 jsmeix@suse.de
- BZR_revision_7085_7084.diff makes the code working
  with Poppler >= 0.23.x see
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1144
- Version upgrade to cups-filters-1.0.35
  that provides in particular various bugfixes,
  for details see the NEWS and README files.
* Fri Apr 19 2013 jsmeix@suse.de
- Version upgrade to cups-filters-1.0.34
  that provides in particular various enhancements for
  cups-browsed, for details see the NEWS and README files.
* Wed Mar 13 2013 jsmeix@suse.de
- Version upgrade to cups-filters-1.0.30
- cups-filters-1.0.30 does no longer build for openSUSE 12.1
  because configure requests 'glib-2.0 >= 2.30.2' but
  version of GLib in openSUSE 12.1 is 2.30.1.
* Fri Jan  4 2013 jsmeix@suse.de
- Version upgrade to cups-filters-1.0.29
  that adds cups-browsed.
- fix_cups-browsed_init_script.patch
  adds LSB header line to cups-browsed init script
  otherwise the openSUSE brp-55-boot-scripts aborts build
  with "ERROR: found one or more broken init or boot scripts"
  and this patch changes "$avahi-daemon $cups" to "avahi cupsd"
  because there is no $avahi-daemon $cups in /etc/insserv.conf
  but /etc/init.d/avahi-daemon "Provides: avahi"
  and /etc/init.d/cups "Provides: cupsd"
  otherwise RPMLINT reports "init-script-undefined-dependency"
  and this patch removes runlevel 4 from Default-Start
  otherwise RPMLINT reports "init-script-runlevel-4".
* Fri Jan  4 2013 mmeister@suse.com
- Adapted and simplified spec file to make it build.
* Wed Oct 17 2012 p.drouand@gmail.com
- Initial release
